import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./accordion-menu.component";
import * as i2 from "@angular/common";
/**
 * @description
 * AccordionMenuProxyModule provides an Angular wrapper for the Fabric AccordionMenu web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-accordion-menu>
 *   <!-- Menu content -->
 * </fabric-accordion-menu>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-accordion-menu
 *   [expanded]="true"
 *   [disabled]="false"
 *   (toggle)="handleToggle($event)">
 *   <!-- Menu content -->
 * </fabric-accordion-menu>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-accordion-menu>
 *   <span slot="icon"><!-- Icon content --></span>
 *   <span slot="header">Menu Title</span>
 *   <fabric-accordion-menu-item>Menu Item 1</fabric-accordion-menu-item>
 *   <fabric-accordion-menu-item>Menu Item 2</fabric-accordion-menu-item>
 * </fabric-accordion-menu>
 * ```
 *
 * ## Available Inputs
 * - `expanded: boolean` - Whether the accordion menu is expanded (default: false)
 * - `disabled: boolean` - Whether the accordion menu is disabled (default: false)
 *
 * ## Available Events
 * - `toggle` - Emitted when the accordion menu is toggled
 *   - Example: `<fabric-accordion-menu (toggle)="onToggle($event)"></fabric-accordion-menu>`
 *
 * ## Available Outputs
 * - `toggle: EventEmitter<any>` - Emitted when the accordion menu is toggled
 *
 * ## Available Slots
 * - `icon` - Icon content for the accordion menu header
 * - `header` - Content for the accordion menu header
 * - default - Content for accordion menu items
 *
 * @example
 * // In your module:
 * import { AccordionMenuProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [AccordionMenuProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-accordion-menu
 *   [expanded]="isExpanded"
 *   (toggle)="handleToggle()">
 *   <span slot="header">Menu Section</span>
 *   <fabric-accordion-menu-item>Item 1</fabric-accordion-menu-item>
 *   <fabric-accordion-menu-item>Item 2</fabric-accordion-menu-item>
 * </fabric-accordion-menu>
 */
export declare class AccordionMenuProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AccordionMenuProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<AccordionMenuProxyModule, [typeof i1.AccordionMenuComponent], [typeof i2.CommonModule], [typeof i1.AccordionMenuComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<AccordionMenuProxyModule>;
}
//# sourceMappingURL=accordion-menu.module.d.ts.map