import { ElementRef, EventEmitter, NgZone, Renderer2, OnInit, OnChanges, AfterViewInit, OnDestroy } from '@angular/core';
import { ButtonAppearance, ButtonFormTarget, ButtonShape, ButtonSize, ButtonType } from '@fabric-msft/fabric-web';
import * as i0 from "@angular/core";
/**
 * Angular wrapper component for the Fabric Button web component.
 * Based on the native button element with enhanced styling and functionality.
 */
export declare class ButtonComponent implements OnInit, OnChanges, AfterViewInit, OnDestroy {
    private readonly el;
    private readonly renderer;
    private readonly ngZone;
    /**
     * Reference to NgZone for managing event handling
     */
    readonly zone: NgZone;
    /**
     * The styled appearance of the button
     */
    appearance?: ButtonAppearance;
    /**
     * Whether the button should be focused when the page loads
     */
    autofocus?: boolean;
    /**
     * Whether the button is disabled
     */
    disabled?: boolean;
    /**
     * Whether the button is focusable while disabled
     */
    disabledFocusable: boolean;
    /**
     * The URL that processes the form submission
     */
    formaction?: string;
    /**
     * The id of the form to associate with
     */
    form?: string;
    /**
     * The encoding type for form submission
     */
    formenctype?: string;
    /**
     * The HTTP method for form submission
     */
    formmethod?: string;
    /**
     * Whether to skip form validation on submission
     */
    formnovalidate?: boolean;
    /**
     * The target frame for form submission
     */
    formtarget?: ButtonFormTarget;
    /**
     * Whether the button should only display as an icon
     */
    iconOnly: boolean;
    /**
     * The name of the button for form submission
     */
    name?: string;
    /**
     * The shape of the button
     */
    shape?: ButtonShape;
    /**
     * The size of the button
     */
    size?: ButtonSize;
    /**
     * The type of the button
     */
    type?: ButtonType;
    /**
     * The value attribute for form submission
     */
    value?: string;
    /**
     * Emits when the button is clicked
     */
    readonly click: EventEmitter<CustomEvent<any>>;
    /**
     * Emits when a key is pressed while focused
     */
    readonly keypress: EventEmitter<CustomEvent<any>>;
    constructor(el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    /**
     * Updates the component's properties on the native element
     */
    private updateComponentProperties;
    /**
     * Updates a boolean attribute on the native element
     */
    private updateBooleanAttribute;
    /**
     * Updates a string attribute on the native element
     */
    private updateStringAttribute;
    /**
     * Handles button click events
     */
    private handleClick;
    /**
     * Handles button keypress events
     */
    private handleKeypress;
    /**
     * Initializes component properties
     */
    ngOnInit(): void;
    /**
     * Updates properties when inputs change
     */
    ngOnChanges(): void;
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ButtonComponent, "fabric-button", never, { "appearance": "appearance"; "autofocus": "autofocus"; "disabled": "disabled"; "disabledFocusable": "disabledFocusable"; "formaction": "formaction"; "form": "form"; "formenctype": "formenctype"; "formmethod": "formmethod"; "formnovalidate": "formnovalidate"; "formtarget": "formtarget"; "iconOnly": "iconOnly"; "name": "name"; "shape": "shape"; "size": "size"; "type": "type"; "value": "value"; }, { "click": "click"; "keypress": "keypress"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=button.component.d.ts.map