import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./button.component";
import * as i2 from "@angular/common";
/**
 * @description
 * ButtonProxyModule provides an Angular wrapper for the Fabric Button web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-button>Click me</fabric-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   (click)="handleClick($event)">
 *   Click me
 * </fabric-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Button text
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: ButtonAppearance` - Visual style of the button: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: ButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the button is clicked
 *   - Example: `<fabric-button (click)="onClick($event)">Click me</fabric-button>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Main button text content
 *
 * @example
 * // In your module:
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-button
 *   [appearance]="'primary'"
 *   (click)="handleButtonClick()">
 *   Submit
 * </fabric-button>
 */
export declare class ButtonProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ButtonProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<ButtonProxyModule, [typeof i1.ButtonComponent], [typeof i2.CommonModule], [typeof i1.ButtonComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<ButtonProxyModule>;
}
//# sourceMappingURL=button.module.d.ts.map