import { ElementRef, EventEmitter, NgZone, Renderer2, OnInit, OnChanges, AfterViewInit, OnDestroy } from '@angular/core';
import { CardFocusMode, CardAppearance, CardOrientation } from '@fabric-msft/fabric-web';
import * as i0 from "@angular/core";
/**
 * Angular wrapper component for the Fabric Card web component.
 * Provides a flexible container for content with various appearance and interaction options.
 */
export declare class CardComponent implements OnInit, OnChanges, AfterViewInit, OnDestroy {
    private el;
    private renderer;
    private ngZone;
    /**
     * Reference to NgZone for managing event handling
     */
    zone: NgZone;
    /**
     * Determines how the card handles focus behavior
     */
    focusMode: CardFocusMode;
    /**
     * The styled appearance of the card
     */
    appearance: CardAppearance;
    /**
     * The orientation of the card's content
     */
    orientation: CardOrientation;
    /**
     * Whether the card is disabled
     */
    disabled: boolean;
    /**
     * Whether the card is interactive (clickable/focusable)
     */
    interactive: boolean;
    /**
     * ID of the element that describes the card
     */
    ariaDescribedby: string;
    /**
     * ID of the element that labels the card
     */
    ariaLabelledby: string;
    /**
     * Emits when the card is clicked
     */
    click: EventEmitter<any>;
    /**
     * Emits when the interactive state changes
     */
    interactiveChanged: EventEmitter<any>;
    constructor(el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    /**
     * Updates the component's properties on the native element
     */
    private updateComponentProperties;
    /**
     * Handles card click events
     */
    private handleClick;
    /**
     * Handles changes to the card's interactive state
     */
    private handleInteractiveChanged;
    /**
     * Initializes component properties
     */
    ngOnInit(): void;
    /**
     * Updates properties when inputs change
     */
    ngOnChanges(): void;
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CardComponent, "fabric-card", never, { "focusMode": "focusMode"; "appearance": "appearance"; "orientation": "orientation"; "disabled": "disabled"; "interactive": "interactive"; "ariaDescribedby": "ariaDescribedby"; "ariaLabelledby": "ariaLabelledby"; }, { "click": "click"; "interactiveChanged": "interactiveChanged"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=card.component.d.ts.map