/**
 * @description
 * CardProxyModule provides an Angular wrapper for the Fabric Card web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-card>
 *   Card content
 * </fabric-card>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-card
 *   [appearance]="'filled'"
 *   [orientation]="'vertical'"
 *   [size]="'medium'"
 *   [disabled]="false">
 *   Card content
 * </fabric-card>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-card>
 *   <fabric-card-header>
 *     Card Title
 *   </fabric-card-header>
 *
 *   <fabric-card-preview>
 *     <!-- Preview content like images -->
 *     <img src="image.jpg" alt="Preview image">
 *   </fabric-card-preview>
 *
 *   <!-- Main card content -->
 *   <p>Card content goes here</p>
 *
 *   <fabric-card-footer>
 *     <fabric-button>Action</fabric-button>
 *   </fabric-card-footer>
 * </fabric-card>
 * ```
 *
 * ## Available Inputs
 * - `appearance: CardAppearance` - Visual style of the card: 'filled' | 'outline' | 'subtle' (default: 'filled')
 * - `orientation: CardOrientation` - Layout direction: 'horizontal' | 'vertical' (default: 'vertical')
 * - `size: CardSize` - Size of the card: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the card is disabled (default: false)
 *
 * ## Available Slots
 * - Default slot - Main content of the card
 * - Card can contain these component slots:
 *   - `<fabric-card-header>` - Header section of the card
 *   - `<fabric-card-preview>` - Preview/media section of the card
 *   - `<fabric-card-footer>` - Footer section with actions
 *
 * @example
 * // In your module:
 * import { CardProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardHeaderProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardFooterProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardPreviewProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     CardProxyModule,
 *     CardHeaderProxyModule,
 *     CardFooterProxyModule,
 *     CardPreviewProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-card [appearance]="'filled'" [orientation]="'vertical'">
 *   <fabric-card-header>Card Title</fabric-card-header>
 *   <p>Card content</p>
 *   <fabric-card-footer>
 *     <fabric-button>Action</fabric-button>
 *   </fabric-card-footer>
 * </fabric-card>
 */
import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./card.component";
import * as i2 from "@angular/common";
export declare class CardProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CardProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<CardProxyModule, [typeof i1.CardComponent], [typeof i2.CommonModule], [typeof i1.CardComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<CardProxyModule>;
}
//# sourceMappingURL=card.module.d.ts.map