import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./carousel.component";
import * as i2 from "@angular/common";
/**
 * @description
 * CarouselProxyModule provides an Angular wrapper for the Fabric Carousel web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-carousel>
 *   <!-- Carousel items -->
 *   <div>Item 1</div>
 *   <div>Item 2</div>
 *   <div>Item 3</div>
 * </fabric-carousel>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-carousel
 *   [disableAnimation]="true">
 *   <!-- Carousel items -->
 *   <div>Item 1</div>
 *   <div>Item 2</div>
 *   <div>Item 3</div>
 * </fabric-carousel>
 * ```
 *
 * ## With Card Components
 * ```html
 * <fabric-carousel>
 *   <fabric-card>
 *     <fabric-card-header>Card 1</fabric-card-header>
 *     <fabric-card-preview>
 *       <img src="image1.jpg" alt="Preview image">
 *     </fabric-card-preview>
 *     <p>Card content</p>
 *   </fabric-card>
 *
 *   <fabric-card>
 *     <fabric-card-header>Card 2</fabric-card-header>
 *     <fabric-card-preview>
 *       <img src="image2.jpg" alt="Preview image">
 *     </fabric-card-preview>
 *     <p>Card content</p>
 *   </fabric-card>
 * </fabric-carousel>
 * ```
 *
 * ## Available Inputs
 * - `disableAnimation: boolean` - Boolean attribute to disable animation (default: false)
 *
 * ## Available Slots
 * - Default slot - Items to be displayed in the carousel
 *
 * @example
 * // In your module:
 * import { CarouselProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     CarouselProxyModule,
 *     CardProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-carousel [disableAnimation]="isAnimationDisabled">
 *   <div *ngFor="let item of items">
 *     {{item.content}}
 *   </div>
 * </fabric-carousel>
 */
export declare class CarouselProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CarouselProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<CarouselProxyModule, [typeof i1.CarouselComponent], [typeof i2.CommonModule], [typeof i1.CarouselComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<CarouselProxyModule>;
}
//# sourceMappingURL=carousel.module.d.ts.map