import * as i0 from '@angular/core';
import { EventEmitter, Component, ChangeDetectionStrategy, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { AccordionMenuDefinition, AccordionMenuPanelDefinition, ButtonDefinition, FilterPillDefinition, LoadingButtonDefinition, CardDefinition, CardFooterDefinition, CardHeaderDefinition, CardPreviewDefinition, CarouselDefinition, MenuButtonDefinition, MenuItemDefinition, MenuListDefinition, MenuDefinition, PopoverDefinition, MessageBarDefinition, MultiViewControllerDefinition, MultiViewGroupDefinition, MultiViewDefinition, SvgIconDefinition, TagDefinition, TeachingBubbleDefinition, TableDefinition, TableCellDefinition, TooltipDefinition, WizardPanelDefinition, WizardStepDefinition, WizardDefinition } from '@fabric-msft/fabric-web';
export { fabricDarkTheme, fabricLightTheme, setTheme, webDarkTheme, webLightTheme } from '@fabric-msft/theme';

class AccordionMenuComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.change = new EventEmitter();
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.expandMode) {
            this.renderer.setAttribute(nativeElement, 'expand-mode', String(this.expandMode));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('change', this.handleChange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('change', this.handleChange);
    }
}
AccordionMenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
AccordionMenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: AccordionMenuComponent, selector: "fabric-accordion-menu", inputs: { expandMode: "expandMode" }, outputs: { change: "change" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-accordion-menu',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { expandMode: [{
                type: Input
            }], change: [{
                type: Output
            }] } });

/**
 * @description
 * AccordionMenuProxyModule provides an Angular wrapper for the Fabric AccordionMenu web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-accordion-menu>
 *   <!-- Menu content -->
 * </fabric-accordion-menu>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-accordion-menu
 *   [expanded]="true"
 *   [disabled]="false"
 *   (toggle)="handleToggle($event)">
 *   <!-- Menu content -->
 * </fabric-accordion-menu>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-accordion-menu>
 *   <span slot="icon"><!-- Icon content --></span>
 *   <span slot="header">Menu Title</span>
 *   <fabric-accordion-menu-item>Menu Item 1</fabric-accordion-menu-item>
 *   <fabric-accordion-menu-item>Menu Item 2</fabric-accordion-menu-item>
 * </fabric-accordion-menu>
 * ```
 *
 * ## Available Inputs
 * - `expanded: boolean` - Whether the accordion menu is expanded (default: false)
 * - `disabled: boolean` - Whether the accordion menu is disabled (default: false)
 *
 * ## Available Events
 * - `toggle` - Emitted when the accordion menu is toggled
 *   - Example: `<fabric-accordion-menu (toggle)="onToggle($event)"></fabric-accordion-menu>`
 *
 * ## Available Outputs
 * - `toggle: EventEmitter<any>` - Emitted when the accordion menu is toggled
 *
 * ## Available Slots
 * - `icon` - Icon content for the accordion menu header
 * - `header` - Content for the accordion menu header
 * - default - Content for accordion menu items
 *
 * @example
 * // In your module:
 * import { AccordionMenuProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [AccordionMenuProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-accordion-menu
 *   [expanded]="isExpanded"
 *   (toggle)="handleToggle()">
 *   <span slot="header">Menu Section</span>
 *   <fabric-accordion-menu-item>Item 1</fabric-accordion-menu-item>
 *   <fabric-accordion-menu-item>Item 2</fabric-accordion-menu-item>
 * </fabric-accordion-menu>
 */
class AccordionMenuProxyModule {
    constructor() {
        AccordionMenuDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
AccordionMenuProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AccordionMenuProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuProxyModule, declarations: [AccordionMenuComponent], imports: [CommonModule], exports: [AccordionMenuComponent] });
AccordionMenuProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AccordionMenuComponent],
                    imports: [CommonModule],
                    exports: [AccordionMenuComponent]
                }]
        }], ctorParameters: function () { return []; } });

class AccordionMenuPanelComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.expanded = false;
        this.disabled = false;
        this.block = false;
        this.change = new EventEmitter();
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.headingLevel) {
            this.renderer.setAttribute(nativeElement, 'heading-level', String(this.headingLevel));
        }
        if (this.expanded) {
            this.renderer.setAttribute(nativeElement, 'expanded', '');
        }
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.id) {
            this.renderer.setAttribute(nativeElement, 'id', String(this.id));
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', String(this.size));
        }
        if (this.block) {
            this.renderer.setAttribute(nativeElement, 'block', '');
        }
        if (this.markerPosition) {
            this.renderer.setAttribute(nativeElement, 'marker-position', String(this.markerPosition));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('change', this.handleChange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('change', this.handleChange);
    }
}
AccordionMenuPanelComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
AccordionMenuPanelComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: AccordionMenuPanelComponent, selector: "fabric-accordion-menu-panel", inputs: { headingLevel: "headingLevel", expanded: "expanded", disabled: "disabled", id: "id", size: "size", block: "block", markerPosition: "markerPosition" }, outputs: { change: "change" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-accordion-menu-panel',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { headingLevel: [{
                type: Input
            }], expanded: [{
                type: Input
            }], disabled: [{
                type: Input
            }], id: [{
                type: Input
            }], size: [{
                type: Input
            }], block: [{
                type: Input
            }], markerPosition: [{
                type: Input
            }], change: [{
                type: Output
            }] } });

class AccordionMenuPanelProxyModule {
    constructor() {
        AccordionMenuPanelDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
AccordionMenuPanelProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AccordionMenuPanelProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelProxyModule, declarations: [AccordionMenuPanelComponent], imports: [CommonModule], exports: [AccordionMenuPanelComponent] });
AccordionMenuPanelProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AccordionMenuPanelProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AccordionMenuPanelComponent],
                    imports: [CommonModule],
                    exports: [AccordionMenuPanelComponent]
                }]
        }], ctorParameters: function () { return []; } });

/**
 * Angular wrapper component for the Fabric Button web component.
 * Based on the native button element with enhanced styling and functionality.
 */
class ButtonComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        /**
         * Whether the button is focusable while disabled
         */
        this.disabledFocusable = false;
        /**
         * Whether the button should only display as an icon
         */
        this.iconOnly = false;
        /**
         * Emits when the button is clicked
         */
        this.click = new EventEmitter();
        /**
         * Emits when a key is pressed while focused
         */
        this.keypress = new EventEmitter();
        /**
         * Handles button click events
         */
        this.handleClick = (event) => {
            if (this.disabledFocusable) {
                event.stopPropagation();
                return;
            }
            this.zone.run(() => {
                this.click.emit(event);
            });
        };
        /**
         * Handles button keypress events
         */
        this.handleKeypress = (event) => {
            if (this.disabledFocusable) {
                event.stopPropagation();
                return;
            }
            this.zone.run(() => {
                this.keypress.emit(event);
            });
        };
        this.zone = ngZone;
    }
    /**
     * Updates the component's properties on the native element
     */
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        // Update boolean attributes
        this.updateBooleanAttribute('autofocus', this.autofocus);
        this.updateBooleanAttribute('disabled', this.disabled);
        this.updateBooleanAttribute('disabled-focusable', this.disabledFocusable);
        this.updateBooleanAttribute('formnovalidate', this.formnovalidate);
        this.updateBooleanAttribute('icon-only', this.iconOnly);
        // Update string attributes
        this.updateStringAttribute('appearance', this.appearance);
        this.updateStringAttribute('formaction', this.formaction);
        this.updateStringAttribute('form', this.form);
        this.updateStringAttribute('formenctype', this.formenctype);
        this.updateStringAttribute('formmethod', this.formmethod);
        this.updateStringAttribute('formtarget', this.formtarget);
        this.updateStringAttribute('name', this.name);
        this.updateStringAttribute('shape', this.shape);
        this.updateStringAttribute('size', this.size);
        this.updateStringAttribute('type', this.type);
        this.updateStringAttribute('value', this.value);
    }
    /**
     * Updates a boolean attribute on the native element
     */
    updateBooleanAttribute(name, value) {
        const nativeElement = this.el.nativeElement;
        if (value) {
            this.renderer.setAttribute(nativeElement, name, '');
        }
        else {
            this.renderer.removeAttribute(nativeElement, name);
        }
    }
    /**
     * Updates a string attribute on the native element
     */
    updateStringAttribute(name, value) {
        const nativeElement = this.el.nativeElement;
        if (value) {
            this.renderer.setAttribute(nativeElement, name, String(value));
        }
        else {
            this.renderer.removeAttribute(nativeElement, name);
        }
    }
    /**
     * Initializes component properties
     */
    ngOnInit() {
        this.updateComponentProperties();
    }
    /**
     * Updates properties when inputs change
     */
    ngOnChanges() {
        this.updateComponentProperties();
    }
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('click', this.handleClick);
        this.el.nativeElement.addEventListener('keypress', this.handleKeypress);
    }
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('click', this.handleClick);
        this.el.nativeElement.removeEventListener('keypress', this.handleKeypress);
    }
}
ButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ButtonComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
ButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ButtonComponent, selector: "fabric-button", inputs: { appearance: "appearance", autofocus: "autofocus", disabled: "disabled", disabledFocusable: "disabledFocusable", formaction: "formaction", form: "form", formenctype: "formenctype", formmethod: "formmethod", formnovalidate: "formnovalidate", formtarget: "formtarget", iconOnly: "iconOnly", name: "name", shape: "shape", size: "size", type: "type", value: "value" }, outputs: { click: "click", keypress: "keypress" }, host: { attributes: { "role": "button", "tabindex": "0" } }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-button',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    host: {
                        role: 'button',
                        tabindex: '0'
                    }
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { appearance: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], disabled: [{
                type: Input
            }], disabledFocusable: [{
                type: Input
            }], formaction: [{
                type: Input
            }], form: [{
                type: Input
            }], formenctype: [{
                type: Input
            }], formmethod: [{
                type: Input
            }], formnovalidate: [{
                type: Input
            }], formtarget: [{
                type: Input
            }], iconOnly: [{
                type: Input
            }], name: [{
                type: Input
            }], shape: [{
                type: Input
            }], size: [{
                type: Input
            }], type: [{
                type: Input
            }], value: [{
                type: Input
            }], click: [{
                type: Output
            }], keypress: [{
                type: Output
            }] } });

/**
 * @description
 * ButtonProxyModule provides an Angular wrapper for the Fabric Button web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-button>Click me</fabric-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   (click)="handleClick($event)">
 *   Click me
 * </fabric-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Button text
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: ButtonAppearance` - Visual style of the button: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: ButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the button is clicked
 *   - Example: `<fabric-button (click)="onClick($event)">Click me</fabric-button>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Main button text content
 *
 * @example
 * // In your module:
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-button
 *   [appearance]="'primary'"
 *   (click)="handleButtonClick()">
 *   Submit
 * </fabric-button>
 */
class ButtonProxyModule {
    constructor() {
        // Define the base web component
        ButtonDefinition.define();
    }
    ngDoBootstrap(appRef) {
        // Required for standalone usage
    }
}
ButtonProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ButtonProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ButtonProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: ButtonProxyModule, declarations: [ButtonComponent], imports: [CommonModule], exports: [ButtonComponent] });
ButtonProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ButtonProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ButtonProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ButtonComponent],
                    imports: [CommonModule],
                    exports: [ButtonComponent]
                }]
        }], ctorParameters: function () { return []; } });

class FilterPillComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.role = "button";
        this.iconOnly = false;
        this.disabledFocusable = false;
        this.pressedchange = new EventEmitter();
        this.click = new EventEmitter();
        this.keypress = new EventEmitter();
        this.handlePressedchange = (event) => {
            this.zone.run(() => {
                this.pressedchange.emit(event.detail);
            });
        };
        this.handleClick = (event) => {
            this.zone.run(() => {
                this.click.emit(event.detail);
            });
        };
        this.handleKeypress = (event) => {
            this.zone.run(() => {
                this.keypress.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.appearance) {
            this.renderer.setAttribute(nativeElement, 'appearance', String(this.appearance));
        }
        if (this.shape) {
            this.renderer.setAttribute(nativeElement, 'shape', String(this.shape));
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', String(this.size));
        }
        if (this.iconOnly) {
            this.renderer.setAttribute(nativeElement, 'icon-only', '');
        }
        if (this.pressed) {
            this.renderer.setAttribute(nativeElement, 'pressed', '');
        }
        if (this.mixed) {
            this.renderer.setAttribute(nativeElement, 'mixed', '');
        }
        if (this.ariaPressed) {
            this.renderer.setAttribute(nativeElement, 'aria-pressed', String(this.ariaPressed));
        }
        if (this.ariaLabel) {
            this.renderer.setAttribute(nativeElement, 'aria-label', String(this.ariaLabel));
        }
        if (this.autofocus) {
            this.renderer.setAttribute(nativeElement, 'autofocus', '');
        }
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.disabledFocusable) {
            this.renderer.setAttribute(nativeElement, 'disabled-focusable', '');
        }
        if (this.formaction) {
            this.renderer.setAttribute(nativeElement, 'formaction', String(this.formaction));
        }
        if (this.form) {
            this.renderer.setAttribute(nativeElement, 'form', String(this.form));
        }
        if (this.formenctype) {
            this.renderer.setAttribute(nativeElement, 'formenctype', String(this.formenctype));
        }
        if (this.formmethod) {
            this.renderer.setAttribute(nativeElement, 'formmethod', String(this.formmethod));
        }
        if (this.formnovalidate) {
            this.renderer.setAttribute(nativeElement, 'formnovalidate', String(this.formnovalidate));
        }
        if (this.formtarget) {
            this.renderer.setAttribute(nativeElement, 'formtarget', String(this.formtarget));
        }
        if (this.name) {
            this.renderer.setAttribute(nativeElement, 'name', String(this.name));
        }
        if (this.type) {
            this.renderer.setAttribute(nativeElement, 'type', String(this.type));
        }
        if (this.value) {
            this.renderer.setAttribute(nativeElement, 'value', String(this.value));
        }
        if (this.role) {
            this.renderer.setAttribute(nativeElement, 'role', this.role);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('pressedchange', this.handlePressedchange);
        this.el.nativeElement.addEventListener('click', this.handleClick);
        this.el.nativeElement.addEventListener('keypress', this.handleKeypress);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('pressedchange', this.handlePressedchange);
        this.el.nativeElement.removeEventListener('click', this.handleClick);
        this.el.nativeElement.removeEventListener('keypress', this.handleKeypress);
    }
}
FilterPillComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterPillComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
FilterPillComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: FilterPillComponent, selector: "fabric-filter-pill", inputs: { role: "role", appearance: "appearance", shape: "shape", size: "size", iconOnly: "iconOnly", pressed: "pressed", mixed: "mixed", ariaPressed: "ariaPressed", ariaLabel: "ariaLabel", autofocus: "autofocus", disabled: "disabled", disabledFocusable: "disabledFocusable", formaction: "formaction", form: "form", formenctype: "formenctype", formmethod: "formmethod", formnovalidate: "formnovalidate", formtarget: "formtarget", name: "name", type: "type", value: "value" }, outputs: { pressedchange: "pressedchange", click: "click", keypress: "keypress" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterPillComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-filter-pill',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { role: [{
                type: Input
            }], appearance: [{
                type: Input
            }], shape: [{
                type: Input
            }], size: [{
                type: Input
            }], iconOnly: [{
                type: Input
            }], pressed: [{
                type: Input
            }], mixed: [{
                type: Input
            }], ariaPressed: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], disabled: [{
                type: Input
            }], disabledFocusable: [{
                type: Input
            }], formaction: [{
                type: Input
            }], form: [{
                type: Input
            }], formenctype: [{
                type: Input
            }], formmethod: [{
                type: Input
            }], formnovalidate: [{
                type: Input
            }], formtarget: [{
                type: Input
            }], name: [{
                type: Input
            }], type: [{
                type: Input
            }], value: [{
                type: Input
            }], pressedchange: [{
                type: Output
            }], click: [{
                type: Output
            }], keypress: [{
                type: Output
            }] } });

/**
 * @description
 * FilterPillProxyModule provides an Angular wrapper for the Fabric FilterPill web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-filter-pill>Filter Label</fabric-filter-pill>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-filter-pill
 *   [appearance]="'primary'"
 *   [shape]="'rounded'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   [selected]="true"
 *   (click)="handleClick($event)">
 *   Filter Label
 * </fabric-filter-pill>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-filter-pill>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Filter Label
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-filter-pill>
 * ```
 *
 * ## Available Inputs
 * - `appearance: FilterPillAppearance` - Visual style of the filter pill: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `shape: FilterPillShape` - Shape of the filter pill: 'rounded' | 'circular' | 'square' (default: 'rounded')
 * - `size: FilterPillSize` - Size of the filter pill: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the filter pill is disabled (default: false)
 * - `selected: boolean` - Whether the filter pill is selected (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the filter pill is clicked
 *   - Example: `<fabric-filter-pill (click)="onFilterClick($event)">Filter</fabric-filter-pill>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the filter pill text
 * - `endIcon` - Icon displayed after the filter pill text
 * - Default slot - Main filter pill text content
 *
 * @example
 * // In your module:
 * import { FilterPillProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [FilterPillProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-filter-pill
 *   [appearance]="'primary'"
 *   [selected]="isSelected"
 *   (click)="toggleFilter()">
 *   Category
 * </fabric-filter-pill>
 */
class FilterPillProxyModule {
    constructor() {
        FilterPillDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
FilterPillProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterPillProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
FilterPillProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: FilterPillProxyModule, declarations: [FilterPillComponent], imports: [CommonModule], exports: [FilterPillComponent] });
FilterPillProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterPillProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: FilterPillProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FilterPillComponent],
                    imports: [CommonModule],
                    exports: [FilterPillComponent]
                }]
        }], ctorParameters: function () { return []; } });

class LoadingButtonComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.loading = false;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.loading) {
            this.renderer.setAttribute(nativeElement, 'loading', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
LoadingButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
LoadingButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: LoadingButtonComponent, selector: "fabric-loading-button", inputs: { loading: "loading" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-loading-button',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { loading: [{
                type: Input
            }] } });

/**
 * @description
 * LoadingButtonProxyModule provides an Angular wrapper for the Fabric LoadingButton web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-loading-button>Click me</fabric-loading-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-loading-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [shape]="'rounded'"
 *   [disabled]="false"
 *   [loading]="isLoading"
 *   (click)="handleClick($event)">
 *   Click me
 * </fabric-loading-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-loading-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Button text
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-loading-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: ButtonAppearance` - Visual style of the button: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: ButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `shape: ButtonShape` - Shape of the button: 'rounded' | 'circular' | 'square' (default: 'rounded')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `loading: boolean` - Whether the button is in loading state (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the button is clicked
 *   - Example: `<fabric-loading-button (click)="onClick($event)">Click me</fabric-loading-button>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Main button text content
 *
 * @example
 * // In your module:
 * import { LoadingButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [LoadingButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-loading-button
 *   [appearance]="'primary'"
 *   [loading]="isSubmitting"
 *   (click)="submitForm()">
 *   Submit
 * </fabric-loading-button>
 */
class LoadingButtonProxyModule {
    constructor() {
        LoadingButtonDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
LoadingButtonProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
LoadingButtonProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonProxyModule, declarations: [LoadingButtonComponent], imports: [CommonModule], exports: [LoadingButtonComponent] });
LoadingButtonProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LoadingButtonProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [LoadingButtonComponent],
                    imports: [CommonModule],
                    exports: [LoadingButtonComponent]
                }]
        }], ctorParameters: function () { return []; } });

/**
 * Angular wrapper component for the Fabric Card web component.
 * Provides a flexible container for content with various appearance and interaction options.
 */
class CardComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        /**
         * Whether the card is disabled
         */
        this.disabled = false;
        /**
         * Whether the card is interactive (clickable/focusable)
         */
        this.interactive = false;
        /**
         * Emits when the card is clicked
         */
        this.click = new EventEmitter();
        /**
         * Emits when the interactive state changes
         */
        this.interactiveChanged = new EventEmitter();
        /**
         * Handles card click events
         */
        this.handleClick = (event) => {
            this.zone.run(() => {
                this.click.emit(event.detail);
            });
        };
        /**
         * Handles changes to the card's interactive state
         */
        this.handleInteractiveChanged = (event) => {
            this.zone.run(() => {
                this.interactiveChanged.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    /**
     * Updates the component's properties on the native element
     */
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.focusMode) {
            this.renderer.setAttribute(nativeElement, 'focus-mode', String(this.focusMode));
        }
        if (this.appearance) {
            this.renderer.setAttribute(nativeElement, 'appearance', String(this.appearance));
        }
        if (this.orientation) {
            this.renderer.setAttribute(nativeElement, 'orientation', String(this.orientation));
        }
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.interactive) {
            this.renderer.setAttribute(nativeElement, 'interactive', '');
        }
        if (this.ariaDescribedby) {
            this.renderer.setAttribute(nativeElement, 'aria-describedby', String(this.ariaDescribedby));
        }
        if (this.ariaLabelledby) {
            this.renderer.setAttribute(nativeElement, 'aria-labelledby', String(this.ariaLabelledby));
        }
    }
    /**
     * Initializes component properties
     */
    ngOnInit() {
        this.updateComponentProperties();
    }
    /**
     * Updates properties when inputs change
     */
    ngOnChanges() {
        this.updateComponentProperties();
    }
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('click', this.handleClick);
        this.el.nativeElement.addEventListener('interactiveChanged', this.handleInteractiveChanged);
    }
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('click', this.handleClick);
        this.el.nativeElement.removeEventListener('interactiveChanged', this.handleInteractiveChanged);
    }
}
CardComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
CardComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CardComponent, selector: "fabric-card", inputs: { focusMode: "focusMode", appearance: "appearance", orientation: "orientation", disabled: "disabled", interactive: "interactive", ariaDescribedby: "ariaDescribedby", ariaLabelledby: "ariaLabelledby" }, outputs: { click: "click", interactiveChanged: "interactiveChanged" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-card',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { focusMode: [{
                type: Input
            }], appearance: [{
                type: Input
            }], orientation: [{
                type: Input
            }], disabled: [{
                type: Input
            }], interactive: [{
                type: Input
            }], ariaDescribedby: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], click: [{
                type: Output
            }], interactiveChanged: [{
                type: Output
            }] } });

/**
 * @description
 * CardProxyModule provides an Angular wrapper for the Fabric Card web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-card>
 *   Card content
 * </fabric-card>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-card
 *   [appearance]="'filled'"
 *   [orientation]="'vertical'"
 *   [size]="'medium'"
 *   [disabled]="false">
 *   Card content
 * </fabric-card>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-card>
 *   <fabric-card-header>
 *     Card Title
 *   </fabric-card-header>
 *
 *   <fabric-card-preview>
 *     <!-- Preview content like images -->
 *     <img src="image.jpg" alt="Preview image">
 *   </fabric-card-preview>
 *
 *   <!-- Main card content -->
 *   <p>Card content goes here</p>
 *
 *   <fabric-card-footer>
 *     <fabric-button>Action</fabric-button>
 *   </fabric-card-footer>
 * </fabric-card>
 * ```
 *
 * ## Available Inputs
 * - `appearance: CardAppearance` - Visual style of the card: 'filled' | 'outline' | 'subtle' (default: 'filled')
 * - `orientation: CardOrientation` - Layout direction: 'horizontal' | 'vertical' (default: 'vertical')
 * - `size: CardSize` - Size of the card: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the card is disabled (default: false)
 *
 * ## Available Slots
 * - Default slot - Main content of the card
 * - Card can contain these component slots:
 *   - `<fabric-card-header>` - Header section of the card
 *   - `<fabric-card-preview>` - Preview/media section of the card
 *   - `<fabric-card-footer>` - Footer section with actions
 *
 * @example
 * // In your module:
 * import { CardProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardHeaderProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardFooterProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardPreviewProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     CardProxyModule,
 *     CardHeaderProxyModule,
 *     CardFooterProxyModule,
 *     CardPreviewProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-card [appearance]="'filled'" [orientation]="'vertical'">
 *   <fabric-card-header>Card Title</fabric-card-header>
 *   <p>Card content</p>
 *   <fabric-card-footer>
 *     <fabric-button>Action</fabric-button>
 *   </fabric-card-footer>
 * </fabric-card>
 */
class CardProxyModule {
    constructor() {
        CardDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
CardProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CardProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: CardProxyModule, declarations: [CardComponent], imports: [CommonModule], exports: [CardComponent] });
CardProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CardComponent],
                    imports: [CommonModule],
                    exports: [CardComponent]
                }]
        }], ctorParameters: function () { return []; } });

class CardFooterComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
}
CardFooterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardFooterComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
CardFooterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CardFooterComponent, selector: "fabric-card-footer", ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardFooterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-card-footer',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; } });

class CardFooterProxyModule {
    constructor() {
        CardFooterDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
CardFooterProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardFooterProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CardFooterProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: CardFooterProxyModule, declarations: [CardFooterComponent], imports: [CommonModule], exports: [CardFooterComponent] });
CardFooterProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardFooterProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardFooterProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CardFooterComponent],
                    imports: [CommonModule],
                    exports: [CardFooterComponent]
                }]
        }], ctorParameters: function () { return []; } });

class CardHeaderComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
}
CardHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
CardHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CardHeaderComponent, selector: "fabric-card-header", ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-card-header',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; } });

class CardHeaderProxyModule {
    constructor() {
        CardHeaderDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
CardHeaderProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CardHeaderProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderProxyModule, declarations: [CardHeaderComponent], imports: [CommonModule], exports: [CardHeaderComponent] });
CardHeaderProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardHeaderProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CardHeaderComponent],
                    imports: [CommonModule],
                    exports: [CardHeaderComponent]
                }]
        }], ctorParameters: function () { return []; } });

class CardPreviewComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.fullWidth) {
            this.renderer.setAttribute(nativeElement, 'full-width', String(this.fullWidth));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
CardPreviewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
CardPreviewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CardPreviewComponent, selector: "fabric-card-preview", inputs: { fullWidth: "fullWidth" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-card-preview',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { fullWidth: [{
                type: Input
            }] } });

class CardPreviewProxyModule {
    constructor() {
        CardPreviewDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
CardPreviewProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CardPreviewProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewProxyModule, declarations: [CardPreviewComponent], imports: [CommonModule], exports: [CardPreviewComponent] });
CardPreviewProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CardPreviewProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CardPreviewComponent],
                    imports: [CommonModule],
                    exports: [CardPreviewComponent]
                }]
        }], ctorParameters: function () { return []; } });

class CarouselComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.disableAnimation) {
            this.renderer.setAttribute(nativeElement, 'disable-animation', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
CarouselComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CarouselComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
CarouselComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: CarouselComponent, selector: "fabric-carousel", inputs: { disableAnimation: "disableAnimation" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CarouselComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-carousel',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { disableAnimation: [{
                type: Input
            }] } });

/**
 * @description
 * CarouselProxyModule provides an Angular wrapper for the Fabric Carousel web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-carousel>
 *   <!-- Carousel items -->
 *   <div>Item 1</div>
 *   <div>Item 2</div>
 *   <div>Item 3</div>
 * </fabric-carousel>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-carousel
 *   [disableAnimation]="true">
 *   <!-- Carousel items -->
 *   <div>Item 1</div>
 *   <div>Item 2</div>
 *   <div>Item 3</div>
 * </fabric-carousel>
 * ```
 *
 * ## With Card Components
 * ```html
 * <fabric-carousel>
 *   <fabric-card>
 *     <fabric-card-header>Card 1</fabric-card-header>
 *     <fabric-card-preview>
 *       <img src="image1.jpg" alt="Preview image">
 *     </fabric-card-preview>
 *     <p>Card content</p>
 *   </fabric-card>
 *
 *   <fabric-card>
 *     <fabric-card-header>Card 2</fabric-card-header>
 *     <fabric-card-preview>
 *       <img src="image2.jpg" alt="Preview image">
 *     </fabric-card-preview>
 *     <p>Card content</p>
 *   </fabric-card>
 * </fabric-carousel>
 * ```
 *
 * ## Available Inputs
 * - `disableAnimation: boolean` - Boolean attribute to disable animation (default: false)
 *
 * ## Available Slots
 * - Default slot - Items to be displayed in the carousel
 *
 * @example
 * // In your module:
 * import { CarouselProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { CardProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     CarouselProxyModule,
 *     CardProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-carousel [disableAnimation]="isAnimationDisabled">
 *   <div *ngFor="let item of items">
 *     {{item.content}}
 *   </div>
 * </fabric-carousel>
 */
class CarouselProxyModule {
    constructor() {
        CarouselDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
CarouselProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CarouselProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CarouselProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: CarouselProxyModule, declarations: [CarouselComponent], imports: [CommonModule], exports: [CarouselComponent] });
CarouselProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CarouselProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: CarouselProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CarouselComponent],
                    imports: [CommonModule],
                    exports: [CarouselComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MenuButtonComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.disabledFocusable = false;
        this.iconOnly = false;
        this.click = new EventEmitter();
        this.keypress = new EventEmitter();
        this.handleClick = (event) => {
            this.zone.run(() => {
                this.click.emit(event.detail);
            });
        };
        this.handleKeypress = (event) => {
            this.zone.run(() => {
                this.keypress.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.appearance) {
            this.renderer.setAttribute(nativeElement, 'appearance', String(this.appearance));
        }
        if (this.autofocus) {
            this.renderer.setAttribute(nativeElement, 'autofocus', '');
        }
        if (this.disabledFocusable) {
            this.renderer.setAttribute(nativeElement, 'disabled-focusable', '');
        }
        if (this.formaction) {
            this.renderer.setAttribute(nativeElement, 'formaction', String(this.formaction));
        }
        if (this.form) {
            this.renderer.setAttribute(nativeElement, 'form', String(this.form));
        }
        if (this.formenctype) {
            this.renderer.setAttribute(nativeElement, 'formenctype', String(this.formenctype));
        }
        if (this.formmethod) {
            this.renderer.setAttribute(nativeElement, 'formmethod', String(this.formmethod));
        }
        if (this.formnovalidate) {
            this.renderer.setAttribute(nativeElement, 'formnovalidate', String(this.formnovalidate));
        }
        if (this.formtarget) {
            this.renderer.setAttribute(nativeElement, 'formtarget', String(this.formtarget));
        }
        if (this.iconOnly) {
            this.renderer.setAttribute(nativeElement, 'icon-only', '');
        }
        if (this.name) {
            this.renderer.setAttribute(nativeElement, 'name', String(this.name));
        }
        if (this.shape) {
            this.renderer.setAttribute(nativeElement, 'shape', String(this.shape));
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', String(this.size));
        }
        if (this.type) {
            this.renderer.setAttribute(nativeElement, 'type', String(this.type));
        }
        if (this.value) {
            this.renderer.setAttribute(nativeElement, 'value', String(this.value));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('click', this.handleClick);
        this.el.nativeElement.addEventListener('keypress', this.handleKeypress);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('click', this.handleClick);
        this.el.nativeElement.removeEventListener('keypress', this.handleKeypress);
    }
}
MenuButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MenuButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MenuButtonComponent, selector: "fabric-menu-button", inputs: { disabled: "disabled", appearance: "appearance", autofocus: "autofocus", disabledFocusable: "disabledFocusable", formaction: "formaction", form: "form", formenctype: "formenctype", formmethod: "formmethod", formnovalidate: "formnovalidate", formtarget: "formtarget", iconOnly: "iconOnly", name: "name", shape: "shape", size: "size", type: "type", value: "value" }, outputs: { click: "click", keypress: "keypress" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-menu-button',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { disabled: [{
                type: Input
            }], appearance: [{
                type: Input
            }], autofocus: [{
                type: Input
            }], disabledFocusable: [{
                type: Input
            }], formaction: [{
                type: Input
            }], form: [{
                type: Input
            }], formenctype: [{
                type: Input
            }], formmethod: [{
                type: Input
            }], formnovalidate: [{
                type: Input
            }], formtarget: [{
                type: Input
            }], iconOnly: [{
                type: Input
            }], name: [{
                type: Input
            }], shape: [{
                type: Input
            }], size: [{
                type: Input
            }], type: [{
                type: Input
            }], value: [{
                type: Input
            }], click: [{
                type: Output
            }], keypress: [{
                type: Output
            }] } });

/**
 * @description
 * MenuButtonProxyModule provides an Angular wrapper for the Fabric MenuButton web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-button>
 *   Menu Button
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   [expanded]="isExpanded"
 *   (click)="handleClick($event)"
 *   (toggle)="handleToggle($event)">
 *   Menu Button
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Menu Button Text
 *   <span slot="endIcon"><svg>...</svg></span>
 *
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: MenuButtonAppearance` - Visual style: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: MenuButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `expanded: boolean` - Whether the associated menu is expanded (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the menu button is clicked
 *   - Example: `<fabric-menu-button (click)="onClick($event)">Menu</fabric-menu-button>`
 * - `toggle` - Emitted when the menu is toggled open or closed
 *   - Example: `<fabric-menu-button (toggle)="onToggle($event)">Menu</fabric-menu-button>`
 *
 * ## Available Outputs
 * - `click: EventEmitter<any>` - Emitted when the menu button is clicked
 * - `toggle: EventEmitter<any>` - Emitted when the menu is toggled open or closed
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Contains the button text and the menu element
 *
 * @example
 * // In your module:
 * import { MenuButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MenuButtonProxyModule,
 *     MenuProxyModule,
 *     MenuItemProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-button
 *   [appearance]="'primary'"
 *   [expanded]="isMenuOpen"
 *   (toggle)="toggleMenu($event)">
 *   Settings
 *   <fabric-menu>
 *     <fabric-menu-item (click)="onSelectOption('profile')">Profile</fabric-menu-item>
 *     <fabric-menu-item (click)="onSelectOption('preferences')">Preferences</fabric-menu-item>
 *     <fabric-menu-item (click)="onSelectOption('logout')">Logout</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 */
class MenuButtonProxyModule {
    constructor() {
        MenuButtonDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MenuButtonProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MenuButtonProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonProxyModule, declarations: [MenuButtonComponent], imports: [CommonModule], exports: [MenuButtonComponent] });
MenuButtonProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuButtonProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MenuButtonComponent],
                    imports: [CommonModule],
                    exports: [MenuButtonComponent]
                }]
        }], ctorParameters: function () { return []; } });

/**
 * Angular wrapper component for the Fabric Menu Item web component.
 * Represents an interactive menu item with support for various roles and states.
 */
class MenuItemComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        /**
         * Whether the menu item is checked (for checkable menu items)
         */
        this.checked = false;
        /**
         * Emits when the menu item state changes
         */
        this.change = new EventEmitter();
        /**
         * Handles menu item state changes
         */
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event);
            });
        };
        this.zone = ngZone;
    }
    /**
     * Updates the component's properties on the native element
     */
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        else {
            this.renderer.removeAttribute(nativeElement, 'disabled');
        }
        if (this.role) {
            this.renderer.setAttribute(nativeElement, 'role', String(this.role));
        }
        if (this.checked) {
            this.renderer.setAttribute(nativeElement, 'checked', '');
        }
        else {
            this.renderer.removeAttribute(nativeElement, 'checked');
        }
        if (this.hidden) {
            this.renderer.setAttribute(nativeElement, 'hidden', '');
        }
        else {
            this.renderer.removeAttribute(nativeElement, 'hidden');
        }
    }
    /**
     * Initializes component properties
     */
    ngOnInit() {
        this.updateComponentProperties();
    }
    /**
     * Updates properties when inputs change
     */
    ngOnChanges() {
        this.updateComponentProperties();
    }
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('change', this.handleChange);
    }
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('change', this.handleChange);
    }
}
MenuItemComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuItemComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MenuItemComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MenuItemComponent, selector: "fabric-menu-item", inputs: { disabled: "disabled", role: "role", checked: "checked", hidden: "hidden" }, outputs: { change: "change" }, host: { attributes: { "role": "menuitem", "tabindex": "-1" } }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuItemComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-menu-item',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    host: {
                        role: 'menuitem',
                        tabindex: '-1'
                    }
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { disabled: [{
                type: Input
            }], role: [{
                type: Input
            }], checked: [{
                type: Input
            }], hidden: [{
                type: Input
            }], change: [{
                type: Output
            }] } });

/**
 * @description
 * MenuItemProxyModule provides an Angular wrapper for the Fabric MenuItem web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-item>Menu Item Text</fabric-menu-item>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-item
 *   [disabled]="false"
 *   [selected]="false"
 *   [checked]="false"
 *   (click)="handleClick($event)">
 *   Menu Item Text
 * </fabric-menu-item>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu-item>
 *   <!-- Optional icon before text -->
 *   <span slot="startIcon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Menu item text -->
 *   Menu Item Text
 *
 *   <!-- Optional icon after text -->
 *   <span slot="endIcon">
 *     <svg>...</svg>
 *   </span>
 * </fabric-menu-item>
 * ```
 *
 * ## Available Inputs
 * - `disabled: boolean` - Whether the menu item is disabled (default: false)
 * - `selected: boolean` - Whether the menu item is selected (default: false)
 * - `checked: boolean` - Whether the menu item is checked, for checkbox/radio variants (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the menu item is clicked
 *   - Example: `<fabric-menu-item (click)="onMenuItemClick($event)">Item</fabric-menu-item>`
 * - `select` - Emitted when the menu item is selected
 *   - Example: `<fabric-menu-item (select)="onMenuItemSelect($event)">Item</fabric-menu-item>`
 *
 * ## Available Outputs
 * - `click: EventEmitter<any>` - Emitted when the menu item is clicked
 * - `select: EventEmitter<any>` - Emitted when the menu item is selected
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the menu item text
 * - `endIcon` - Icon displayed after the menu item text
 * - Default slot - Main menu item text content
 *
 * @example
 * // In your module:
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuItemProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-list>
 *   <fabric-menu-item
 *     [disabled]="isDisabled"
 *     (click)="handleItemClick()">
 *     Settings
 *   </fabric-menu-item>
 *   <fabric-menu-item
 *     [checked]="isChecked"
 *     (click)="toggleOption()">
 *     Enable feature
 *   </fabric-menu-item>
 * </fabric-menu-list>
 */
class MenuItemProxyModule {
    constructor() {
        MenuItemDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MenuItemProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuItemProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MenuItemProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MenuItemProxyModule, declarations: [MenuItemComponent], imports: [CommonModule], exports: [MenuItemComponent] });
MenuItemProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuItemProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuItemProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MenuItemComponent],
                    imports: [CommonModule],
                    exports: [MenuItemComponent]
                }]
        }], ctorParameters: function () { return []; } });

/**
 * Angular wrapper component for the Fabric Menu List web component.
 * Provides a list container for menu items with keyboard navigation and accessibility support.
 */
class MenuListComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        /**
         * Emits when a menu item selection changes
         */
        this.change = new EventEmitter();
        /**
         * Emits when a keyboard event occurs on the menu list
         */
        this.keydown = new EventEmitter();
        /**
         * Emits when the expanded state of the menu list changes
         */
        this.expandedChange = new EventEmitter();
        /**
         * Handles menu item selection changes
         */
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event);
            });
        };
        /**
         * Handles keyboard events
         */
        this.handleKeydown = (event) => {
            this.zone.run(() => {
                this.keydown.emit(event);
            });
        };
        /**
         * Handles expanded state changes
         */
        this.handleExpandedChange = (event) => {
            this.zone.run(() => {
                this.expandedChange.emit(event);
            });
        };
        this.zone = ngZone;
    }
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('change', this.handleChange);
        this.el.nativeElement.addEventListener('keydown', this.handleKeydown);
        this.el.nativeElement.addEventListener('expanded-change', this.handleExpandedChange);
    }
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('change', this.handleChange);
        this.el.nativeElement.removeEventListener('keydown', this.handleKeydown);
        this.el.nativeElement.removeEventListener('expanded-change', this.handleExpandedChange);
    }
}
MenuListComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuListComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MenuListComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MenuListComponent, selector: "fabric-menu-list", outputs: { change: "change", keydown: "keydown", expandedChange: "expandedChange" }, host: { attributes: { "role": "menu", "tabindex": "0" } }, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuListComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-menu-list',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    host: {
                        role: 'menu',
                        tabindex: '0'
                    }
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { change: [{
                type: Output
            }], keydown: [{
                type: Output
            }], expandedChange: [{
                type: Output
            }] } });

/**
 * @description
 * MenuListProxyModule provides an Angular wrapper for the Fabric MenuList web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-list>
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu-list>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-list
 *   [disabled]="false"
 *   [appearance]="'subtle'"
 *   (selectionChange)="handleSelectionChange($event)">
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu-list>
 * ```
 *
 * ## Available Inputs
 * - `disabled: boolean` - Whether the menu list is disabled (default: false)
 * - `appearance: MenuListAppearance` - Visual style of the menu list: 'subtle' | 'default' (default: 'default')
 *
 * ## Available Events
 * - `selectionChange` - Emitted when an item is selected from the menu list
 *   - Example: `<fabric-menu-list (selectionChange)="onSelectionChange($event)"></fabric-menu-list>`
 *
 * ## Available Outputs
 * - `selectionChange: EventEmitter<any>` - Emitted when menu item selection changes
 *
 * ## Available Slots
 * - Default slot - Content for menu items
 *
 * @example
 * // In your module:
 * import { MenuListProxyModule, MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuListProxyModule, MenuItemProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-list
 *   [appearance]="menuAppearance"
 *   (selectionChange)="handleMenuSelection($event)">
 *   <fabric-menu-item *ngFor="let item of menuItems">
 *     {{item.label}}
 *   </fabric-menu-item>
 * </fabric-menu-list>
 */
class MenuListProxyModule {
    constructor() {
        // Define the base web component
        MenuListDefinition.define();
    }
    ngDoBootstrap(appRef) {
        // Required for standalone usage
    }
}
MenuListProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuListProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MenuListProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MenuListProxyModule, declarations: [MenuListComponent], imports: [CommonModule], exports: [MenuListComponent] });
MenuListProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuListProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuListProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MenuListComponent],
                    imports: [CommonModule],
                    exports: [MenuListComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MenuComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.openOnHover = false;
        this.openOnContext = false;
        this.closeOnScroll = false;
        this.persistOnItemClick = false;
        this.toggle = new EventEmitter();
        this.change = new EventEmitter();
        this.handleToggle = (event) => {
            this.zone.run(() => {
                this.toggle.emit(event.detail);
            });
        };
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.openOnHover) {
            this.renderer.setAttribute(nativeElement, 'open-on-hover', '');
        }
        if (this.openOnContext) {
            this.renderer.setAttribute(nativeElement, 'open-on-context', '');
        }
        if (this.closeOnScroll) {
            this.renderer.setAttribute(nativeElement, 'close-on-scroll', '');
        }
        if (this.persistOnItemClick) {
            this.renderer.setAttribute(nativeElement, 'persist-on-item-click', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('toggle', this.handleToggle);
        this.el.nativeElement.addEventListener('change', this.handleChange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('toggle', this.handleToggle);
        this.el.nativeElement.removeEventListener('change', this.handleChange);
    }
}
MenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MenuComponent, selector: "fabric-menu", inputs: { openOnHover: "openOnHover", openOnContext: "openOnContext", closeOnScroll: "closeOnScroll", persistOnItemClick: "persistOnItemClick" }, outputs: { toggle: "toggle", change: "change" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-menu',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { openOnHover: [{
                type: Input
            }], openOnContext: [{
                type: Input
            }], closeOnScroll: [{
                type: Input
            }], persistOnItemClick: [{
                type: Input
            }], toggle: [{
                type: Output
            }], change: [{
                type: Output
            }] } });

/**
 * @description
 * MenuProxyModule provides an Angular wrapper for the Fabric Menu web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu>
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu
 *   [open]="isMenuOpen"
 *   [anchor]="'bottom-start'"
 *   [positioning]="'fixed'"
 *   (openChange)="handleOpenChange($event)">
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu>
 *   <!-- Trigger element (usually a button) -->
 *   <fabric-button slot="trigger">
 *     Open Menu
 *   </fabric-button>
 *
 *   <!-- Menu items -->
 *   <fabric-menu-item>Option 1</fabric-menu-item>
 *   <fabric-menu-item>Option 2</fabric-menu-item>
 *   <fabric-menu-item disabled>Option 3 (Disabled)</fabric-menu-item>
 *
 *   <!-- Divider -->
 *   <fabric-divider></fabric-divider>
 *
 *   <!-- More menu items -->
 *   <fabric-menu-item>Option 4</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## Available Inputs
 * - `open: boolean` - Whether the menu is open (default: false)
 * - `anchor: MenuAnchor` - How to position the menu relative to its anchor: 'top-start' | 'top' | 'top-end' | 'bottom-start' | 'bottom' | 'bottom-end' | 'start-top' | 'start' | 'start-bottom' | 'end-top' | 'end' | 'end-bottom' (default: 'bottom-start')
 * - `positioning: MenuPositioning` - How to position the menu: 'fixed' | 'absolute' | 'auto' (default: 'auto')
 * - `offset: number` - Distance in pixels between the menu and its anchor (default: 0)
 * - `autoFocus: boolean` - Whether to automatically focus the first item when opened (default: true)
 *
 * ## Available Events
 * - `openChange` - Emitted when the menu's open state changes
 *   - Example: `<fabric-menu (openChange)="onOpenChange($event)"></fabric-menu>`
 * - `select` - Emitted when a menu item is selected
 *   - Example: `<fabric-menu (select)="onMenuItemSelect($event)"></fabric-menu>`
 *
 * ## Available Outputs
 * - `openChange: EventEmitter<boolean>` - Emitted when the menu's open state changes
 * - `select: EventEmitter<any>` - Emitted when a menu item is selected
 *
 * ## Available Slots
 * - `trigger` - Content that serves as the trigger for the menu
 * - Default slot - Menu items (usually `<fabric-menu-item>` elements)
 *
 * @example
 * // In your module:
 * import { MenuProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuProxyModule, MenuItemProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu
 *   [open]="isMenuOpen"
 *   (openChange)="handleOpenChange($event)"
 *   (select)="handleMenuSelect($event)">
 *   <fabric-button slot="trigger">Open Menu</fabric-button>
 *   <fabric-menu-item>Profile</fabric-menu-item>
 *   <fabric-menu-item>Settings</fabric-menu-item>
 *   <fabric-menu-item>Logout</fabric-menu-item>
 * </fabric-menu>
 */
class MenuProxyModule {
    constructor() {
        MenuDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MenuProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MenuProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MenuProxyModule, declarations: [MenuComponent], imports: [CommonModule], exports: [MenuComponent] });
MenuProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MenuProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MenuComponent],
                    imports: [CommonModule],
                    exports: [MenuComponent]
                }]
        }], ctorParameters: function () { return []; } });

class PopoverComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.beak = false;
        this.nonClickable = false;
        this.size = 'medium';
        this.mode = 'manual';
        this.repositionMode = 'flip';
        this.open = false;
        this.transitionDuration = 100;
        this.transitionDelay = 0;
        this.hide = new EventEmitter();
        this.show = new EventEmitter();
        this.toggle = new EventEmitter();
        this.mouseEnter = new EventEmitter();
        this.mouseLeave = new EventEmitter();
        this.handleHide = (event) => {
            this.zone.run(() => {
                this.hide.emit(event.detail);
            });
        };
        this.handleShow = (event) => {
            this.zone.run(() => {
                this.show.emit(event.detail);
            });
        };
        this.handleToggle = (event) => {
            this.zone.run(() => {
                this.toggle.emit(event.detail);
            });
        };
        this.handleMouseEnter = (event) => {
            this.zone.run(() => {
                this.mouseEnter.emit(event.detail);
            });
        };
        this.handleMouseLeave = (event) => {
            this.zone.run(() => {
                this.mouseLeave.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        this.renderer.setProperty(nativeElement, 'open', this.open);
        if (this.beak) {
            this.renderer.setAttribute(nativeElement, 'beak', '');
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', this.size);
        }
        if (this.mode) {
            this.renderer.setAttribute(nativeElement, 'mode', this.mode);
        }
        if (this.position) {
            this.renderer.setAttribute(nativeElement, 'position', this.position);
        }
        if (this.targetId) {
            this.renderer.setAttribute(nativeElement, 'target-id', this.targetId);
        }
        if (this.repositionMode) {
            this.renderer.setAttribute(nativeElement, 'reposition-mode', this.repositionMode);
        }
        if (this.overflowBoundarySelector) {
            this.renderer.setAttribute(nativeElement, 'overflow-boundary-selector', this.overflowBoundarySelector);
        }
        if (this.ariaLabel) {
            this.renderer.setAttribute(nativeElement, 'aria-label', this.ariaLabel);
        }
        if (this.nonClickable) {
            this.renderer.setAttribute(nativeElement, 'non-clickable', '');
        }
        if (this.transitionDuration !== undefined) {
            this.renderer.setAttribute(nativeElement, 'transition-duration', String(this.transitionDuration));
        }
        if (this.transitionDelay !== undefined) {
            this.renderer.setAttribute(nativeElement, 'transition-delay', String(this.transitionDelay));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('hide', this.handleHide);
        this.el.nativeElement.addEventListener('show', this.handleShow);
        this.el.nativeElement.addEventListener('toggle', this.handleToggle);
        this.el.nativeElement.addEventListener('mouseEnter', this.handleMouseEnter);
        this.el.nativeElement.addEventListener('mouseLeave', this.handleMouseLeave);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('hide', this.handleHide);
        this.el.nativeElement.removeEventListener('show', this.handleShow);
        this.el.nativeElement.removeEventListener('toggle', this.handleToggle);
        this.el.nativeElement.removeEventListener('mouseEnter', this.handleMouseEnter);
        this.el.nativeElement.removeEventListener('mouseLeave', this.handleMouseLeave);
    }
}
PopoverComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PopoverComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
PopoverComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: PopoverComponent, selector: "fabric-popover", inputs: { beak: "beak", nonClickable: "nonClickable", size: "size", mode: "mode", position: "position", targetId: "targetId", repositionMode: "repositionMode", open: "open", overflowBoundarySelector: "overflowBoundarySelector", ariaLabel: "ariaLabel", transitionDuration: "transitionDuration", transitionDelay: "transitionDelay" }, outputs: { hide: "hide", show: "show", toggle: "toggle", mouseEnter: "mouseEnter", mouseLeave: "mouseLeave" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PopoverComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-popover',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { beak: [{
                type: Input
            }], nonClickable: [{
                type: Input
            }], size: [{
                type: Input
            }], mode: [{
                type: Input
            }], position: [{
                type: Input
            }], targetId: [{
                type: Input
            }], repositionMode: [{
                type: Input
            }], open: [{
                type: Input
            }], overflowBoundarySelector: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], transitionDuration: [{
                type: Input
            }], transitionDelay: [{
                type: Input
            }], hide: [{
                type: Output
            }], show: [{
                type: Output
            }], toggle: [{
                type: Output
            }], mouseEnter: [{
                type: Output
            }], mouseLeave: [{
                type: Output
            }] } });

/**
 * @description
 * PopoverProxyModule provides an Angular wrapper for the Fabric Popover web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-popover>
 *   <button slot="trigger">Click me</button>
 *   <div>Popover content</div>
 * </fabric-popover>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-popover
 *   [open]="isPopoverOpen"
 *   [placement]="'top'"
 *   [beak]="true"
 *   [mode]="'auto'"
 *   (hide)="onPopoverHide($event)"
 *   (show)="onPopoverShow($event)">
 *   <button slot="trigger">Click me</button>
 *   <div>Popover content</div>
 * </fabric-popover>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-popover>
 *   <!-- Element that triggers the popover -->
 *   <button slot="trigger">Open popover</button>
 *
 *   <!-- Content inside the popover -->
 *   <div>
 *     <h3>Popover Title</h3>
 *     <p>Popover content</p>
 *     <fabric-button>Action</fabric-button>
 *   </div>
 * </fabric-popover>
 * ```
 *
 * ## Available Inputs
 * - `open: boolean` - Whether the popover is open (default: false)
 * - `beak: boolean` - Whether the popover has a visual beak/arrow pointer (default: false)
 * - `nonClickable: boolean` - Indicates if the popover anchor is not clickable (default: false)
 * - `size: PopoverSize` - Size of the popover: 'small' | 'medium' | 'large' (default: 'medium')
 * - `mode: PopoverMode` - Behavior mode: 'auto' | 'manual' (default: 'manual')
 * - `position: PositioningShorthandValues` - Position of the popover relative to its anchor
 * - `targetId: string` - ID of the target element to anchor the popover to
 * - `repositionMode: PopoverRepositionMode` - How the popover repositions: 'flip' | 'none' (default: 'flip')
 * - `overflowBoundarySelector: string` - CSS selector for the overflow boundary container
 * - `ariaLabel: string` - ARIA label for accessibility
 * - `transitionDuration: number` - Duration of popover transition in ms (default: 100)
 * - `transitionDelay: number` - Delay before popover transition in ms (default: 0)
 *
 * ## Available Events
 * - `hide` - Emitted when the popover is hidden
 *   - Example: `<fabric-popover (hide)="onHide($event)"></fabric-popover>`
 * - `show` - Emitted when the popover is shown
 *   - Example: `<fabric-popover (show)="onShow($event)"></fabric-popover>`
 * - `toggle` - Emitted when the popover visibility is toggled
 *   - Example: `<fabric-popover (toggle)="onToggle($event)"></fabric-popover>`
 * - `mouseEnter` - Emitted when mouse enters the popover
 *   - Example: `<fabric-popover (mouseEnter)="onMouseEnter($event)"></fabric-popover>`
 * - `mouseLeave` - Emitted when mouse leaves the popover
 *   - Example: `<fabric-popover (mouseLeave)="onMouseLeave($event)"></fabric-popover>`
 *
 * ## Available Outputs
 * - `hide: EventEmitter<any>` - Emitted when the popover is hidden
 * - `show: EventEmitter<any>` - Emitted when the popover is shown
 * - `toggle: EventEmitter<any>` - Emitted when the popover visibility is toggled
 * - `mouseEnter: EventEmitter<any>` - Emitted when mouse enters the popover
 * - `mouseLeave: EventEmitter<any>` - Emitted when mouse leaves the popover
 *
 * ## Available Slots
 * - `trigger` - Element that triggers the popover
 * - Default slot - Content to display in the popover
 *
 * @example
 * // In your module:
 * import { PopoverProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [PopoverProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-popover
 *   [open]="isPopoverVisible"
 *   [position]="'top'"
 *   [beak]="true"
 *   (show)="onShowPopover()"
 *   (hide)="onHidePopover()">
 *   <fabric-button slot="trigger">Show info</fabric-button>
 *   <div>
 *     <h3>Additional Information</h3>
 *     <p>This provides more context about the feature.</p>
 *   </div>
 * </fabric-popover>
 */
class PopoverProxyModule {
    constructor() {
        PopoverDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
PopoverProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PopoverProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
PopoverProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: PopoverProxyModule, declarations: [PopoverComponent], imports: [CommonModule], exports: [PopoverComponent] });
PopoverProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PopoverProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: PopoverProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [PopoverComponent],
                    imports: [CommonModule],
                    exports: [PopoverComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MessageBarComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.shape) {
            this.renderer.setAttribute(nativeElement, 'shape', this.shape);
        }
        if (this.layout) {
            this.renderer.setAttribute(nativeElement, 'layout', this.layout);
        }
        if (this.intent) {
            this.renderer.setAttribute(nativeElement, 'intent', this.intent);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
MessageBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MessageBarComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MessageBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MessageBarComponent, selector: "fabric-message-bar", inputs: { shape: "shape", layout: "layout", intent: "intent" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MessageBarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-message-bar',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { shape: [{
                type: Input
            }], layout: [{
                type: Input
            }], intent: [{
                type: Input
            }] } });

/**
 * @description
 * MessageBarProxyModule provides an Angular wrapper for the Fabric MessageBar web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-message-bar>
 *   This is a message bar notification
 * </fabric-message-bar>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-message-bar
 *   [intent]="'info'"
 *   [dismissible]="true"
 *   (dismiss)="handleDismiss($event)">
 *   This is an informational message with a dismiss button
 * </fabric-message-bar>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-message-bar [intent]="'warning'">
 *   <!-- Custom icon -->
 *   <span slot="icon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Message content -->
 *   <span>Warning message content</span>
 *
 *   <!-- Action buttons/links -->
 *   <span slot="action">
 *     <fabric-button>Action</fabric-button>
 *   </span>
 * </fabric-message-bar>
 * ```
 *
 * ## Available Inputs
 * - `intent: MessageBarIntent` - Type of message: 'info' | 'success' | 'warning' | 'error' (default: 'info')
 * - `dismissible: boolean` - Whether the message bar can be dismissed (default: false)
 *
 * ## Available Events
 * - `dismiss` - Emitted when the message bar is dismissed (clicked on dismiss button)
 *   - Example: `<fabric-message-bar [dismissible]="true" (dismiss)="onDismiss()">Message</fabric-message-bar>`
 *
 * ## Available Outputs
 * - `dismiss: EventEmitter<any>` - Emitted when the message bar is dismissed
 *
 * ## Available Slots
 * - `icon` - Custom icon to display
 * - `action` - Area for action buttons or links
 * - Default slot - Main message content
 *
 * @example
 * // In your module:
 * import { MessageBarProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MessageBarProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-message-bar
 *   [intent]="'success'"
 *   [dismissible]="true"
 *   (dismiss)="onMessageDismiss()">
 *   Operation completed successfully!
 *   <span slot="action">
 *     <a href="#">View details</a>
 *   </span>
 * </fabric-message-bar>
 */
class MessageBarProxyModule {
    constructor() {
        MessageBarDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MessageBarProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MessageBarProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MessageBarProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MessageBarProxyModule, declarations: [MessageBarComponent], imports: [CommonModule], exports: [MessageBarComponent] });
MessageBarProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MessageBarProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MessageBarProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MessageBarComponent],
                    imports: [CommonModule],
                    exports: [MessageBarComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MultiViewControllerComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.hidden) {
            this.renderer.setAttribute(nativeElement, 'hidden', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
MultiViewControllerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MultiViewControllerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MultiViewControllerComponent, selector: "fabric-multi-view-controller", inputs: { hidden: "hidden" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-multi-view-controller',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { hidden: [{
                type: Input
            }] } });

/**
 * @description
 * MultiViewControllerProxyModule provides an Angular wrapper for the Fabric MultiViewController web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view-controller>
 *   <!-- Controller content -->
 * </fabric-multi-view-controller>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view-controller
 *   [activeIndex]="0"
 *   [disabled]="false"
 *   (activeIndexChange)="handleViewChange($event)">
 *   <!-- Controller content -->
 * </fabric-multi-view-controller>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-multi-view-controller>
 *   <span slot="previous">Previous</span>
 *   <span slot="next">Next</span>
 *   <span slot="indicator">
 *     <!-- Custom indicators -->
 *   </span>
 * </fabric-multi-view-controller>
 * ```
 *
 * ## Within MultiView Component
 * ```html
 * <fabric-multi-view>
 *   <fabric-multi-view-controller slot="controller">
 *     <!-- Controller content -->
 *   </fabric-multi-view-controller>
 *
 *   <fabric-multi-view-group>
 *     <div>View 1 Content</div>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group>
 *     <div>View 2 Content</div>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## Available Inputs
 * - `activeIndex: number` - The zero-based index of the currently active view (default: 0)
 * - `disabled: boolean` - Whether the controller is disabled (default: false)
 *
 * ## Available Events
 * - `activeIndexChange` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view-controller (activeIndexChange)="onViewChange($event)"></fabric-multi-view-controller>`
 *
 * ## Available Outputs
 * - `activeIndexChange: EventEmitter<number>` - Emitted when the active view changes
 *
 * ## Available Slots
 * - `previous` - Content for the previous button/control
 * - `next` - Content for the next button/control
 * - `indicator` - Content for view indicators
 *
 * @example
 * // In your module:
 * import { MultiViewControllerProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewControllerProxyModule,
 *     MultiViewProxyModule,
 *     MultiViewGroupProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view>
 *   <fabric-multi-view-controller
 *     slot="controller"
 *     [activeIndex]="currentViewIndex"
 *     (activeIndexChange)="onViewChange($event)">
 *   </fabric-multi-view-controller>
 *
 *   <fabric-multi-view-group *ngFor="let view of views">
 *     <div>{{view.content}}</div>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 */
class MultiViewControllerProxyModule {
    constructor() {
        MultiViewControllerDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MultiViewControllerProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MultiViewControllerProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerProxyModule, declarations: [MultiViewControllerComponent], imports: [CommonModule], exports: [MultiViewControllerComponent] });
MultiViewControllerProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewControllerProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MultiViewControllerComponent],
                    imports: [CommonModule],
                    exports: [MultiViewControllerComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MultiViewGroupComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.change = new EventEmitter();
        this.handleChange = (event) => {
            this.zone.run(() => {
                this.change.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('change', this.handleChange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('change', this.handleChange);
    }
}
MultiViewGroupComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MultiViewGroupComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MultiViewGroupComponent, selector: "fabric-multi-view-group", outputs: { change: "change" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-multi-view-group',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { change: [{
                type: Output
            }] } });

/**
 * @description
 * MultiViewGroupProxyModule provides an Angular wrapper for the Fabric MultiViewGroup web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view-group>
 *   <!-- Multi-view content -->
 * </fabric-multi-view-group>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view-group
 *   [active]="currentViewId"
 *   [disabled]="false">
 *   <!-- Multi-view content -->
 * </fabric-multi-view-group>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-multi-view-group>
 *   <fabric-multi-view id="view1">View 1 Content</fabric-multi-view>
 *   <fabric-multi-view id="view2">View 2 Content</fabric-multi-view>
 *   <fabric-multi-view id="view3">View 3 Content</fabric-multi-view>
 * </fabric-multi-view-group>
 * ```
 *
 * ## Available Inputs
 * - `active: string` - ID of the currently active view (default: first view's ID)
 * - `disabled: boolean` - Whether the multi-view group is disabled (default: false)
 *
 * ## Available Events
 * - `change` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view-group (change)="onViewChange($event)"></fabric-multi-view-group>`
 *
 * ## Available Outputs
 * - `change: EventEmitter<any>` - Emitted when the active view changes
 *
 * ## Available Slots
 * - Default slot - Container for fabric-multi-view components
 *
 * @example
 * // In your module:
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewGroupProxyModule,
 *     MultiViewProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view-group
 *   [active]="activeViewId"
 *   (change)="onViewChange($event)">
 *   <fabric-multi-view id="summary">Summary View</fabric-multi-view>
 *   <fabric-multi-view id="details">Details View</fabric-multi-view>
 *   <fabric-multi-view id="settings">Settings View</fabric-multi-view>
 * </fabric-multi-view-group>
 */
class MultiViewGroupProxyModule {
    constructor() {
        MultiViewGroupDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MultiViewGroupProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MultiViewGroupProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupProxyModule, declarations: [MultiViewGroupComponent], imports: [CommonModule], exports: [MultiViewGroupComponent] });
MultiViewGroupProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewGroupProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MultiViewGroupComponent],
                    imports: [CommonModule],
                    exports: [MultiViewGroupComponent]
                }]
        }], ctorParameters: function () { return []; } });

class MultiViewComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.hidden = true;
        this.hiddenchanged = new EventEmitter();
        this.handleHiddenchanged = (event) => {
            this.zone.run(() => {
                this.hiddenchanged.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.hidden) {
            this.renderer.setAttribute(nativeElement, 'hidden', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('hiddenchanged', this.handleHiddenchanged);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('hiddenchanged', this.handleHiddenchanged);
    }
}
MultiViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
MultiViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: MultiViewComponent, selector: "fabric-multi-view", inputs: { hidden: "hidden" }, outputs: { hiddenchanged: "hiddenchanged" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-multi-view',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { hidden: [{
                type: Input
            }], hiddenchanged: [{
                type: Output
            }] } });

/**
 * @description
 * MultiViewProxyModule provides an Angular wrapper for the Fabric MultiView web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view>
 *   <fabric-multi-view-controller></fabric-multi-view-controller>
 *   <fabric-multi-view-group>
 *     <!-- View content -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view
 *   [activeId]="'view1'"
 *   (viewChange)="handleViewChange($event)">
 *   <fabric-multi-view-controller>
 *     <!-- Controller content -->
 *   </fabric-multi-view-controller>
 *   <fabric-multi-view-group>
 *     <!-- View content -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## With Controller and Groups
 * ```html
 * <fabric-multi-view [activeId]="activeViewId">
 *   <!-- Navigation controller -->
 *   <fabric-multi-view-controller>
 *     <button id="view1">View 1</button>
 *     <button id="view2">View 2</button>
 *     <button id="view3">View 3</button>
 *   </fabric-multi-view-controller>
 *
 *   <!-- Content groups -->
 *   <fabric-multi-view-group id="view1">
 *     <h2>View 1 Content</h2>
 *     <p>This is the content for view 1</p>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group id="view2">
 *     <h2>View 2 Content</h2>
 *     <p>This is the content for view 2</p>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group id="view3">
 *     <h2>View 3 Content</h2>
 *     <p>This is the content for view 3</p>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## Available Inputs
 * - `activeId: string` - ID of the currently active view group (default: first view group's ID)
 *
 * ## Available Events
 * - `viewChange` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view (viewChange)="onViewChange($event)"></fabric-multi-view>`
 *
 * ## Available Outputs
 * - `viewChange: EventEmitter<string>` - Emitted when the active view changes, with the new active view ID
 *
 * ## Component Composition
 * MultiView is composed of the following components:
 * - `fabric-multi-view` - The root container component
 * - `fabric-multi-view-controller` - Contains navigation controls for switching views
 * - `fabric-multi-view-group` - Individual view containers with unique IDs
 *
 * @example
 * // In your module:
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewControllerProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewProxyModule,
 *     MultiViewControllerProxyModule,
 *     MultiViewGroupProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view
 *   [activeId]="selectedViewId"
 *   (viewChange)="onViewChange($event)">
 *   <fabric-multi-view-controller>
 *     <!-- Navigation controls -->
 *   </fabric-multi-view-controller>
 *   <fabric-multi-view-group id="view1">
 *     <!-- Content for view 1 -->
 *   </fabric-multi-view-group>
 *   <fabric-multi-view-group id="view2">
 *     <!-- Content for view 2 -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 */
class MultiViewProxyModule {
    constructor() {
        MultiViewDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
MultiViewProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MultiViewProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: MultiViewProxyModule, declarations: [MultiViewComponent], imports: [CommonModule], exports: [MultiViewComponent] });
MultiViewProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: MultiViewProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MultiViewComponent],
                    imports: [CommonModule],
                    exports: [MultiViewComponent]
                }]
        }], ctorParameters: function () { return []; } });

class SvgIconComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.ariaHidden = "true";
        this.focusable = "false";
        this.role = "";
        this.error = new EventEmitter();
        this.handleError = (event) => {
            this.zone.run(() => {
                this.error.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.name) {
            this.renderer.setAttribute(nativeElement, 'name', this.name);
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', this.size);
        }
        if (this.path) {
            this.renderer.setAttribute(nativeElement, 'path', this.path);
        }
        if (this.ariaHidden) {
            this.renderer.setAttribute(nativeElement, 'aria-hidden', this.ariaHidden);
        }
        if (this.focusable) {
            this.renderer.setAttribute(nativeElement, 'focusable', this.focusable);
        }
        if (this.role) {
            this.renderer.setAttribute(nativeElement, 'role', this.role);
        }
        if (this.ariaLabel) {
            this.renderer.setAttribute(nativeElement, 'aria-label', this.ariaLabel);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('error', this.handleError);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('error', this.handleError);
    }
}
SvgIconComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SvgIconComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
SvgIconComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: SvgIconComponent, selector: "fabric-svg-icon", inputs: { name: "name", size: "size", path: "path", ariaHidden: "ariaHidden", focusable: "focusable", role: "role", ariaLabel: "ariaLabel" }, outputs: { error: "error" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SvgIconComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-svg-icon',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { name: [{
                type: Input
            }], size: [{
                type: Input
            }], path: [{
                type: Input
            }], ariaHidden: [{
                type: Input
            }], focusable: [{
                type: Input
            }], role: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], error: [{
                type: Output
            }] } });

/**
 * @description
 * SvgIconProxyModule provides an Angular wrapper for the Fabric SvgIcon web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-svg-icon path="path/to/icons.svg" name="icon-name"></fabric-svg-icon>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-svg-icon
 *   [path]="'assets/icons/icons.svg'"
 *   [name]="'settings'"
 *   [size]="'24'"
 *   [ariaLabel]="'Settings'"
 *   [ariaHidden]="'false'"
 *   (error)="handleIconError($event)">
 * </fabric-svg-icon>
 * ```
 *
 * ## Available Inputs
 * - `name: string` - The name of the SVG to use from the SVG sprite
 * - `size: string` - The size of the icon in pixels: '12' | '16' | '20' | '24' | '28' | '32' | '48' (default: '20')
 * - `path: string` - Path to SVG file (can be standalone SVG or SVG sprite)
 * - `ariaHidden: string` - Whether the icon is hidden from screen readers (default: 'true')
 * - `focusable: string` - Whether the icon is focusable (default: 'false')
 * - `role: string` - The accessibility role of the icon (default: '')
 * - `ariaLabel: string` - Optional label for the icon for accessibility
 *
 * ## Available Events
 * - `error` - Emitted when the icon fails to load
 *   - Example: `<fabric-svg-icon (error)="onIconError($event)"></fabric-svg-icon>`
 *
 * @example
 * // In your module:
 * import { SvgIconProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [SvgIconProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-svg-icon
 *   [path]="'assets/icons/icons.svg'"
 *   [name]="'user'"
 *   [size]="'24'"
 *   [ariaLabel]="'User profile'">
 * </fabric-svg-icon>
 */
class SvgIconProxyModule {
    constructor() {
        SvgIconDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
SvgIconProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SvgIconProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SvgIconProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: SvgIconProxyModule, declarations: [SvgIconComponent], imports: [CommonModule], exports: [SvgIconComponent] });
SvgIconProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SvgIconProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SvgIconProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [SvgIconComponent],
                    imports: [CommonModule],
                    exports: [SvgIconComponent]
                }]
        }], ctorParameters: function () { return []; } });

class TagComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.dismissButton = false;
        this.disabled = false;
        this.size = "medium";
        this.shape = "rounded";
        this.appearance = "filled";
        this.dismiss = new EventEmitter();
        this.handleDismiss = (event) => {
            this.zone.run(() => {
                this.dismiss.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.dismissButton) {
            this.renderer.setAttribute(nativeElement, 'dismiss-button', '');
        }
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', String(this.size));
        }
        if (this.shape) {
            this.renderer.setAttribute(nativeElement, 'shape', String(this.shape));
        }
        if (this.appearance) {
            this.renderer.setAttribute(nativeElement, 'appearance', String(this.appearance));
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('dismiss', this.handleDismiss);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('dismiss', this.handleDismiss);
    }
}
TagComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TagComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
TagComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TagComponent, selector: "fabric-tag", inputs: { dismissButton: "dismissButton", disabled: "disabled", size: "size", shape: "shape", appearance: "appearance" }, outputs: { dismiss: "dismiss" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TagComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-tag',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { dismissButton: [{
                type: Input
            }], disabled: [{
                type: Input
            }], size: [{
                type: Input
            }], shape: [{
                type: Input
            }], appearance: [{
                type: Input
            }], dismiss: [{
                type: Output
            }] } });

/**
 * @description
 * TagProxyModule provides an Angular wrapper for the Fabric Tag web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-tag>Primary Text</fabric-tag>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-tag
 *   [dismissButton]="true"
 *   [disabled]="false"
 *   [size]="'medium'"
 *   [shape]="'rounded'"
 *   [appearance]="'filled'"
 *   (dismiss)="handleDismiss($event)">
 *   Tag Text
 * </fabric-tag>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-tag [dismissButton]="true">
 *   <!-- Leading icon (like SVG) -->
 *   <span slot="leadingIcon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Main text -->
 *   <span slot="text">Primary Text</span>
 *
 *   <!-- Optional secondary text -->
 *   <span slot="textSecondary">Secondary Text</span>
 *
 *   <!-- Optional image/avatar -->
 *   <fluent-avatar slot="image" size="24" initials="JD"></fluent-avatar>
 * </fabric-tag>
 * ```
 *
 * ## Available Inputs
 * - `dismissButton: boolean` - Whether the tag shows a dismiss button (default: false)
 * - `disabled: boolean` - Whether the tag is disabled (default: false)
 * - `size: TagSize` - Size of the tag: 'extraSmall' | 'small' | 'medium' (default: 'medium')
 * - `shape: TagShape` - Shape of the tag: 'rounded' | 'circular' (default: 'rounded')
 * - `appearance: TagAppearance` - Visual style: 'filled' | 'outline' | 'brand' (default: 'filled')
 *
 * ## Available Events
 * - `dismiss` - Emitted when the tag is dismissed (clicked on dismiss button)
 *   - Example: `<fabric-tag [dismissButton]="true" (dismiss)="onTagDismiss()">Text</fabric-tag>`
 *
 * ## Available Outputs
 * - `dismiss: EventEmitter<any>` - Emitted when the dismiss button is clicked
 *
 * ## Available Slots
 * - `image` - For avatar or image content
 * - `leadingIcon` - For icon before the text
 * - `text` - Primary text content (required)
 * - `textSecondary` - Secondary text line
 * - `dismissIcon` - Custom dismiss icon (replaces default)
 *
 * @example
 * // In your module:
 * import { TagProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TagProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-tag
 *   [dismissButton]="true"
 *   [appearance]="'brand'"
 *   (dismiss)="onDismiss()">
 *   <span slot="text">Tag content</span>
 * </fabric-tag>
 */
class TagProxyModule {
    constructor() {
        TagDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
TagProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TagProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TagProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: TagProxyModule, declarations: [TagComponent], imports: [CommonModule], exports: [TagComponent] });
TagProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TagProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TagProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TagComponent],
                    imports: [CommonModule],
                    exports: [TagComponent]
                }]
        }], ctorParameters: function () { return []; } });

class TeachingBubbleComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.target = "";
        this.placement = "top";
        this.disableTrapFocus = false;
        this.size = "medium";
        this.openchange = new EventEmitter();
        this.dismiss = new EventEmitter();
        this.handleOpenchange = (event) => {
            this.zone.run(() => {
                this.openchange.emit(event.detail);
            });
        };
        this.handleDismiss = (event) => {
            this.zone.run(() => {
                this.dismiss.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.target) {
            this.renderer.setAttribute(nativeElement, 'target', this.target);
        }
        if (this.placement) {
            this.renderer.setAttribute(nativeElement, 'placement', this.placement);
        }
        if (this.open) {
            this.renderer.setAttribute(nativeElement, 'open', '');
        }
        if (this.disableTrapFocus) {
            this.renderer.setAttribute(nativeElement, 'disable-trap-focus', '');
        }
        if (this.size) {
            this.renderer.setAttribute(nativeElement, 'size', this.size);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('openchange', this.handleOpenchange);
        this.el.nativeElement.addEventListener('dismiss', this.handleDismiss);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('openchange', this.handleOpenchange);
        this.el.nativeElement.removeEventListener('dismiss', this.handleDismiss);
    }
}
TeachingBubbleComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
TeachingBubbleComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TeachingBubbleComponent, selector: "fabric-teaching-bubble", inputs: { target: "target", placement: "placement", open: "open", disableTrapFocus: "disableTrapFocus", size: "size" }, outputs: { openchange: "openchange", dismiss: "dismiss" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-teaching-bubble',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { target: [{
                type: Input
            }], placement: [{
                type: Input
            }], open: [{
                type: Input
            }], disableTrapFocus: [{
                type: Input
            }], size: [{
                type: Input
            }], openchange: [{
                type: Output
            }], dismiss: [{
                type: Output
            }] } });

/**
 * @description
 * TeachingBubbleProxyModule provides an Angular wrapper for the Fabric TeachingBubble web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-teaching-bubble [target]="'target-element-id'" [open]="isOpen">
 *   Content of the teaching bubble
 * </fabric-teaching-bubble>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-teaching-bubble
 *   [target]="'target-element-id'"
 *   [placement]="'top'"
 *   [open]="isOpen"
 *   [size]="'medium'"
 *   [disableTrapFocus]="false"
 *   (openchange)="handleOpenChange($event)"
 *   (dismiss)="handleDismiss($event)">
 *
 *   Teaching bubble content
 * </fabric-teaching-bubble>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-teaching-bubble [target]="'target-element-id'" [open]="isOpen">
 *   <!-- Image in the teaching bubble -->
 *   <div slot="image">
 *     <img src="example.jpg" alt="Example illustration" />
 *   </div>
 *
 *   <!-- Heading for the teaching bubble -->
 *   <h3 slot="heading">Feature Introduction</h3>
 *
 *   <!-- Main content -->
 *   <p>This feature helps you accomplish your tasks more efficiently.</p>
 *
 *   <!-- Custom close button -->
 *   <button slot="close" aria-label="Close">✕</button>
 *
 *   <!-- Footer with action buttons -->
 *   <div slot="footer">
 *     <fabric-button (click)="onSkip()">Skip</fabric-button>
 *     <fabric-button (click)="onNext()" [appearance]="'primary'">Next</fabric-button>
 *   </div>
 * </fabric-teaching-bubble>
 * ```
 *
 * ## Available Inputs
 * - `target: string` - ID of the target element that the teaching bubble is attached to
 * - `placement: TeachingBubblePlacement` - Placement relative to target: 'top' | 'bottom' | 'left' | 'right' (default: 'top')
 * - `open: boolean` - Whether the teaching bubble is open (default: false)
 * - `disableTrapFocus: boolean` - Whether focus trapping is disabled (default: false)
 * - `size: TeachingBubbleSize` - Size of the teaching bubble: 'small' | 'medium' | 'large' (default: 'medium')
 *
 * ## Available Events
 * - `openchange` - Emitted when the open state changes
 *   - Example: `<fabric-teaching-bubble (openchange)="onOpenChange($event)"></fabric-teaching-bubble>`
 * - `dismiss` - Emitted when the teaching bubble is dismissed
 *   - Example: `<fabric-teaching-bubble (dismiss)="onDismiss($event)"></fabric-teaching-bubble>`
 *
 * ## Available Outputs
 * - `openchange: EventEmitter<any>` - Emitted when the open state changes
 * - `dismiss: EventEmitter<any>` - Emitted when the teaching bubble is dismissed
 *
 * ## Available Slots
 * - `image` - For adding an image to the teaching bubble
 * - `close` - For adding a custom close button
 * - `heading` - For adding a heading to the teaching bubble
 * - `footer` - For adding footer content like action buttons
 * - Default slot - Main content of the teaching bubble
 *
 * @example
 * // In your module:
 * import { TeachingBubbleProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TeachingBubbleProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component:
 * @Component({
 *   selector: 'app-feature-tour',
 *   template: `
 *     <div id="target-feature">
 *       <button (click)="showHelp()">Help</button>
 *     </div>
 *
 *     <fabric-teaching-bubble
 *       [target]="'target-feature'"
 *       [open]="showBubble"
 *       [placement]="'right'"
 *       (dismiss)="onDismiss()">
 *       <h3 slot="heading">Feature Help</h3>
 *       <p>This feature lets you manage your account settings.</p>
 *       <div slot="footer">
 *         <fabric-button (click)="onDismiss()">Got it</fabric-button>
 *       </div>
 *     </fabric-teaching-bubble>
 *   `
 * })
 * export class FeatureTourComponent {
 *   showBubble = false;
 *
 *   showHelp() {
 *     this.showBubble = true;
 *   }
 *
 *   onDismiss() {
 *     this.showBubble = false;
 *   }
 * }
 */
class TeachingBubbleProxyModule {
    constructor() {
        TeachingBubbleDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
TeachingBubbleProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TeachingBubbleProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleProxyModule, declarations: [TeachingBubbleComponent], imports: [CommonModule], exports: [TeachingBubbleComponent] });
TeachingBubbleProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TeachingBubbleProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TeachingBubbleComponent],
                    imports: [CommonModule],
                    exports: [TeachingBubbleComponent]
                }]
        }], ctorParameters: function () { return []; } });

class TableComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.sortable = false;
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.sortable) {
            this.renderer.setAttribute(nativeElement, 'sortable', '');
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
}
TableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
TableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TableComponent, selector: "fabric-table", inputs: { sortable: "sortable" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-table',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { sortable: [{
                type: Input
            }] } });

/**
 * @description
 * TableProxyModule provides an Angular wrapper for the Fabric Table web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-table>
 *   <!-- Table content -->
 * </fabric-table>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-table [sortable]="true">
 *   <!-- Table content with sortable columns -->
 * </fabric-table>
 * ```
 *
 * ## With Content
 * ```html
 * <fabric-table [sortable]="true">
 *   <tr>
 *     <th>Name</th>
 *     <th>Email</th>
 *     <th>Role</th>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>John Doe</fabric-table-cell>
 *     <fabric-table-cell>john.doe@example.com</fabric-table-cell>
 *     <fabric-table-cell>Admin</fabric-table-cell>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>Jane Smith</fabric-table-cell>
 *     <fabric-table-cell>jane.smith@example.com</fabric-table-cell>
 *     <fabric-table-cell>User</fabric-table-cell>
 *   </tr>
 * </fabric-table>
 * ```
 *
 * ## Available Inputs
 * - `sortable: boolean` - Determines if the table has sortable columns (default: false)
 *
 * ## Available Slots
 * - Default slot - The content of the table, including headers and rows
 *
 * @example
 * // In your module:
 * import { TableProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { TableCellProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TableProxyModule, TableCellProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-table [sortable]="true">
 *   <tr>
 *     <th>Name</th>
 *     <th>Department</th>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>John Doe</fabric-table-cell>
 *     <fabric-table-cell>Engineering</fabric-table-cell>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>Jane Smith</fabric-table-cell>
 *     <fabric-table-cell>Design</fabric-table-cell>
 *   </tr>
 * </fabric-table>
 */
class TableProxyModule {
    constructor() {
        TableDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
TableProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TableProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: TableProxyModule, declarations: [TableComponent], imports: [CommonModule], exports: [TableComponent] });
TableProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TableComponent],
                    imports: [CommonModule],
                    exports: [TableComponent]
                }]
        }], ctorParameters: function () { return []; } });

class TableCellComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.hiddenchange = new EventEmitter();
        this.handleHiddenchange = (event) => {
            this.zone.run(() => {
                this.hiddenchange.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('hiddenchange', this.handleHiddenchange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('hiddenchange', this.handleHiddenchange);
    }
}
TableCellComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableCellComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
TableCellComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TableCellComponent, selector: "fabric-table-cell", outputs: { hiddenchange: "hiddenchange" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableCellComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-table-cell',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { hiddenchange: [{
                type: Output
            }] } });

class TableCellProxyModule {
    constructor() {
        TableCellDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
TableCellProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableCellProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TableCellProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: TableCellProxyModule, declarations: [TableCellComponent], imports: [CommonModule], exports: [TableCellComponent] });
TableCellProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableCellProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TableCellProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TableCellComponent],
                    imports: [CommonModule],
                    exports: [TableCellComponent]
                }]
        }], ctorParameters: function () { return []; } });

class TooltipComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.open = false;
        this.beak = false;
        this.hidePopover = new EventEmitter();
        this.showPopover = new EventEmitter();
        this.handleHidePopover = (event) => {
            this.zone.run(() => {
                this.hidePopover.emit(event.detail);
            });
        };
        this.handleShowPopover = (event) => {
            this.zone.run(() => {
                this.showPopover.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.position) {
            const positionValue = this.transformPosition(this.position);
            this.renderer.setAttribute(nativeElement, 'position', positionValue);
        }
        if (this.open) {
            this.renderer.setAttribute(nativeElement, 'open', '');
        }
        if (this.beak) {
            this.renderer.setAttribute(nativeElement, 'beak', '');
        }
        if (this.targetId) {
            this.renderer.setAttribute(nativeElement, 'target-id', this.targetId);
        }
        if (this.transitionDuration !== undefined) {
            this.renderer.setAttribute(nativeElement, 'transition-duration', String(this.transitionDuration));
        }
        if (this.transitionDelay !== undefined) {
            this.renderer.setAttribute(nativeElement, 'transition-delay', String(this.transitionDelay));
        }
    }
    transformPosition(position) {
        // Transform the enum value to a valid DOM attribute value
        // Example transformation logic (to be adjusted as necessary)
        return position.toLowerCase().replace('_', '-');
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('hidePopover', this.handleHidePopover);
        this.el.nativeElement.addEventListener('showPopover', this.handleShowPopover);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('hidePopover', this.handleHidePopover);
        this.el.nativeElement.removeEventListener('showPopover', this.handleShowPopover);
    }
}
TooltipComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TooltipComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
TooltipComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: TooltipComponent, selector: "fabric-tooltip", inputs: { position: "position", open: "open", beak: "beak", targetId: "targetId", transitionDuration: "transitionDuration", transitionDelay: "transitionDelay" }, outputs: { hidePopover: "hidePopover", showPopover: "showPopover" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TooltipComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-tooltip',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { position: [{
                type: Input
            }], open: [{
                type: Input
            }], beak: [{
                type: Input
            }], targetId: [{
                type: Input
            }], transitionDuration: [{
                type: Input
            }], transitionDelay: [{
                type: Input
            }], hidePopover: [{
                type: Output
            }], showPopover: [{
                type: Output
            }] } });

/**
 * @description
 * TooltipProxyModule provides an Angular wrapper for the Fabric Tooltip web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-tooltip>
 *   <span slot="tooltip-trigger">Hover me</span>
 *   <span slot="tooltip-content">Tooltip content</span>
 * </fabric-tooltip>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-tooltip
 *   [position]="'top'"
 *   [open]="isTooltipOpen"
 *   [beak]="true"
 *   [targetId]="'custom-tooltip-id'"
 *   [transitionDuration]="200"
 *   [transitionDelay]="100"
 *   (hidePopover)="onHideTooltip($event)"
 *   (showPopover)="onShowTooltip($event)">
 *   <span slot="tooltip-trigger">Hover me</span>
 *   <span slot="tooltip-content">Tooltip content with custom settings</span>
 * </fabric-tooltip>
 * ```
 *
 * ## Available Inputs
 * - `position: PositioningShorthandValues` - Position of the tooltip relative to the trigger (e.g., 'top', 'bottom', 'left', 'right')
 * - `open: boolean` - Whether the tooltip is open (default: false)
 * - `beak: boolean` - Whether the tooltip has a visual beak/arrow pointer (default: false)
 * - `targetId: string` - Custom ID for the tooltip element (auto-generated if not provided)
 * - `transitionDuration: number` - Duration of tooltip transition in ms (default: 100)
 * - `transitionDelay: number` - Delay before tooltip transition in ms (default: 0)
 *
 * ## Available Events
 * - `hidePopover` - Emitted when the tooltip is hidden
 *   - Example: `<fabric-tooltip (hidePopover)="onHide($event)"></fabric-tooltip>`
 * - `showPopover` - Emitted when the tooltip is shown
 *   - Example: `<fabric-tooltip (showPopover)="onShow($event)"></fabric-tooltip>`
 *
 * ## Available Outputs
 * - `hidePopover: EventEmitter<any>` - Emitted when the tooltip is hidden
 * - `showPopover: EventEmitter<any>` - Emitted when the tooltip is shown
 *
 * ## Available Slots
 * - `tooltip-trigger` - Element that triggers the tooltip
 * - `tooltip-content` - Content to display in the tooltip
 *
 * @example
 * // In your module:
 * import { TooltipProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TooltipProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-tooltip
 *   [position]="'right'"
 *   [beak]="true"
 *   (showPopover)="onTooltipShown()"
 *   (hidePopover)="onTooltipHidden()">
 *   <button slot="tooltip-trigger">Help</button>
 *   <div slot="tooltip-content">
 *     <p>This feature allows you to configure advanced settings.</p>
 *   </div>
 * </fabric-tooltip>
 */
class TooltipProxyModule {
    constructor() {
        TooltipDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
TooltipProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TooltipProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
TooltipProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: TooltipProxyModule, declarations: [TooltipComponent], imports: [CommonModule], exports: [TooltipComponent] });
TooltipProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TooltipProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: TooltipProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TooltipComponent],
                    imports: [CommonModule],
                    exports: [TooltipComponent]
                }]
        }], ctorParameters: function () { return []; } });

class WizardPanelComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.hidden = true;
        this.state = "incomplete";
        this.active = false;
        this.panelchange = new EventEmitter();
        this.handlePanelchange = (event) => {
            this.zone.run(() => {
                this.panelchange.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.hidden) {
            this.renderer.setAttribute(nativeElement, 'hidden', '');
        }
        if (this.state) {
            this.renderer.setAttribute(nativeElement, 'state', this.state);
        }
        if (this.active) {
            this.renderer.setAttribute(nativeElement, 'active', '');
        }
        if (this.id) {
            this.renderer.setAttribute(nativeElement, 'id', this.id);
        }
        if (this.slot) {
            this.renderer.setAttribute(nativeElement, 'slot', this.slot);
        }
        if (this.ariaLabel) {
            this.renderer.setAttribute(nativeElement, 'aria-label', this.ariaLabel);
        }
        if (this.ariaDescribedby) {
            this.renderer.setAttribute(nativeElement, 'aria-describedby', this.ariaDescribedby);
        }
        if (this.ariaLabelledby) {
            this.renderer.setAttribute(nativeElement, 'aria-labelledby', this.ariaLabelledby);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('panelchange', this.handlePanelchange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('panelchange', this.handlePanelchange);
    }
}
WizardPanelComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
WizardPanelComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: WizardPanelComponent, selector: "fabric-wizard-panel", inputs: { hidden: "hidden", state: "state", active: "active", id: "id", slot: "slot", ariaLabel: "ariaLabel", ariaDescribedby: "ariaDescribedby", ariaLabelledby: "ariaLabelledby" }, outputs: { panelchange: "panelchange" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-wizard-panel',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { hidden: [{
                type: Input
            }], state: [{
                type: Input
            }], active: [{
                type: Input
            }], id: [{
                type: Input
            }], slot: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], ariaDescribedby: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], panelchange: [{
                type: Output
            }] } });

/**
 * @description
 * WizardPanelProxyModule provides an Angular wrapper for the Fabric WizardPanel web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard-panel>
 *   Panel content goes here
 * </fabric-wizard-panel>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard-panel
 *   [hidden]="!isCurrentStep"
 *   [active]="isCurrentStep"
 *   [state]="stepState"
 *   [id]="'step-panel-1'"
 *   [slot]="'panel'"
 *   (panelchange)="onPanelChange($event)">
 *   Step content
 * </fabric-wizard-panel>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-wizard-panel>
 *   <div slot="title">Step Title</div>
 *   <div>Main content for this step</div>
 *   <div slot="start">Content at the start</div>
 *   <div slot="end">Content at the end</div>
 *   <div slot="footer">
 *     <fabric-button (click)="goBack()">Back</fabric-button>
 *     <fabric-button (click)="goNext()">Next</fabric-button>
 *   </div>
 * </fabric-wizard-panel>
 * ```
 *
 * ## Available Inputs
 * - `hidden: boolean` - Indicates whether the panel is hidden (default: true)
 * - `state: WizardStepState` - The state of the step: 'incomplete' | 'complete' | 'error' (default: 'incomplete')
 * - `active: boolean` - Indicates whether the panel is currently active (default: false)
 * - `id: string` - The ID of the panel
 * - `slot: string` - The slot of the panel (typically 'panel' when used within a wizard)
 * - `ariaLabel: string` - The aria-label of the panel for accessibility
 * - `ariaDescribedby: string` - The aria-describedby of the panel for accessibility
 * - `ariaLabelledby: string` - The aria-labelledby of the panel for accessibility
 *
 * ## Available Events
 * - `panelchange` - Emitted when the panel state, activity, or visibility changes
 *   - Example: `<fabric-wizard-panel (panelchange)="onPanelChange($event)"></fabric-wizard-panel>`
 *
 * ## Available Outputs
 * - `panelchange: EventEmitter<any>` - Emitted when the panel state changes
 *
 * ## Available Slots
 * - Default slot - The main content of the panel
 * - `start` - Content displayed at the start of the panel
 * - `end` - Content displayed at the end of the panel
 * - `title` - Content displayed as the title of the panel
 * - `footer` - Content displayed in the footer of the panel (typically navigation buttons)
 *
 * @example
 * // In your module:
 * import { WizardPanelProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [WizardPanelProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-wizard-panel
 *   [active]="currentStepIndex === 0"
 *   [state]="step1Completed ? 'complete' : 'incomplete'"
 *   [slot]="'panel'"
 *   (panelchange)="onPanel1Change($event)">
 *   <h3 slot="title">Personal Information</h3>
 *   <div>
 *     <!-- Form fields for personal information -->
 *   </div>
 *   <div slot="footer">
 *     <fabric-button (click)="goToNextStep()">Next</fabric-button>
 *   </div>
 * </fabric-wizard-panel>
 */
class WizardPanelProxyModule {
    constructor() {
        WizardPanelDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
WizardPanelProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
WizardPanelProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelProxyModule, declarations: [WizardPanelComponent], imports: [CommonModule], exports: [WizardPanelComponent] });
WizardPanelProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardPanelProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WizardPanelComponent],
                    imports: [CommonModule],
                    exports: [WizardPanelComponent]
                }]
        }], ctorParameters: function () { return []; } });

class WizardStepComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.active = false;
        this.disabled = false;
        this.state = "incomplete";
        this.stepchange = new EventEmitter();
        this.handleStepchange = (event) => {
            this.zone.run(() => {
                this.stepchange.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.ordered) {
            this.renderer.setAttribute(nativeElement, 'ordered', '');
        }
        if (this.hideConnector) {
            this.renderer.setAttribute(nativeElement, 'hide-connector', '');
        }
        if (this.active) {
            this.renderer.setAttribute(nativeElement, 'active', '');
        }
        if (this.disabled) {
            this.renderer.setAttribute(nativeElement, 'disabled', '');
        }
        if (this.ariaDescribedby) {
            this.renderer.setAttribute(nativeElement, 'aria-describedby', this.ariaDescribedby);
        }
        if (this.ariaLabelledby) {
            this.renderer.setAttribute(nativeElement, 'aria-labelledby', this.ariaLabelledby);
        }
        if (this.state) {
            this.renderer.setAttribute(nativeElement, 'state', this.state);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('stepchange', this.handleStepchange);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('stepchange', this.handleStepchange);
    }
}
WizardStepComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardStepComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
WizardStepComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: WizardStepComponent, selector: "fabric-wizard-step", inputs: { ordered: "ordered", hideConnector: "hideConnector", active: "active", disabled: "disabled", ariaDescribedby: "ariaDescribedby", ariaLabelledby: "ariaLabelledby", state: "state" }, outputs: { stepchange: "stepchange" }, usesOnChanges: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardStepComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-wizard-step',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { ordered: [{
                type: Input
            }], hideConnector: [{
                type: Input
            }], active: [{
                type: Input
            }], disabled: [{
                type: Input
            }], ariaDescribedby: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], state: [{
                type: Input
            }], stepchange: [{
                type: Output
            }] } });

/**
 * @description
 * WizardStepProxyModule provides an Angular wrapper for the Fabric WizardStep web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard-step>Step Label</fabric-wizard-step>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard-step
 *   [ordered]="true"
 *   [hideConnector]="false"
 *   [active]="isActive"
 *   [disabled]="isDisabled"
 *   [state]="'incomplete'"
 *   (stepchange)="onStepChange($event)">
 *   Step Label
 * </fabric-wizard-step>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-wizard-step>
 *   <!-- Default slot content -->
 *   Main step content
 *
 *   <!-- Content for specific states -->
 *   <span slot="incomplete">⚪</span>
 *   <span slot="complete">✓</span>
 *   <span slot="error">⚠️</span>
 *
 *   <!-- Step information -->
 *   <div slot="title">Step Title</div>
 *   <div slot="details">Additional step details</div>
 *
 *   <!-- Positioning content -->
 *   <div slot="start">Content at start</div>
 *   <div slot="end">Content at end</div>
 * </fabric-wizard-step>
 * ```
 *
 * ## Available Inputs
 * - `ordered: boolean` - Indicates whether the step is ordered with a number (default: false)
 * - `hideConnector: boolean` - Indicates whether the visual connector between steps should be hidden (default: false)
 * - `active: boolean` - Indicates whether the step is active (default: false)
 * - `disabled: boolean` - Indicates whether the step is disabled (default: false)
 * - `state: WizardStepState` - The state of the step: 'incomplete' | 'complete' | 'error' (default: 'incomplete')
 * - `ariaDescribedby: string` - The ID of an element that describes the step for accessibility
 * - `ariaLabelledby: string` - The ID of an element that labels the step for accessibility
 *
 * ## Available Events
 * - `stepchange` - Emitted when the step's state or active status changes
 *   - Example: `<fabric-wizard-step (stepchange)="onStepChange($event)"></fabric-wizard-step>`
 *
 * ## Available Outputs
 * - `stepchange: EventEmitter<any>` - Emitted when the step state changes
 *
 * ## Available Slots
 * - Default slot - The main content/label of the step
 * - `start` - Content displayed at the start of the step
 * - `end` - Content displayed at the end of the step
 * - `incomplete` - Content displayed when the step is incomplete
 * - `complete` - Content displayed when the step is complete
 * - `error` - Content displayed when the step has an error
 * - `title` - Content displayed as the title of the step
 * - `details` - Content displayed as additional details for the step
 *
 * @example
 * // In your module:
 * import { WizardStepProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [WizardStepProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-wizard-step
 *   [active]="currentStep === 0"
 *   [state]="step1State"
 *   (stepchange)="handleStepChange($event)">
 *   <div slot="title">Account Information</div>
 *   <div slot="details">Enter your basic account details</div>
 * </fabric-wizard-step>
 */
class WizardStepProxyModule {
    constructor() {
        WizardStepDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
WizardStepProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardStepProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
WizardStepProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: WizardStepProxyModule, declarations: [WizardStepComponent], imports: [CommonModule], exports: [WizardStepComponent] });
WizardStepProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardStepProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardStepProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WizardStepComponent],
                    imports: [CommonModule],
                    exports: [WizardStepComponent]
                }]
        }], ctorParameters: function () { return []; } });

class WizardComponent {
    constructor(el, renderer, ngZone) {
        this.el = el;
        this.renderer = renderer;
        this.ngZone = ngZone;
        this.ordered = false;
        this.disableOnComplete = false;
        this.currentIndex = 0;
        this.wizardchange = new EventEmitter();
        this.wizardcomplete = new EventEmitter();
        this.handleWizardchange = (event) => {
            this.zone.run(() => {
                this.wizardchange.emit(event.detail);
            });
        };
        this.handleWizardcomplete = (event) => {
            this.zone.run(() => {
                this.wizardcomplete.emit(event.detail);
            });
        };
        this.zone = ngZone;
    }
    updateComponentProperties() {
        const nativeElement = this.el.nativeElement;
        if (this.ordered) {
            this.renderer.setAttribute(nativeElement, 'ordered', '');
        }
        if (this.disableOnComplete) {
            this.renderer.setAttribute(nativeElement, 'disable-on-complete', '');
        }
        if (this.currentIndex !== undefined) {
            this.renderer.setAttribute(nativeElement, 'current-index', String(this.currentIndex));
        }
        if (this.ariaLabelledby) {
            this.renderer.setAttribute(nativeElement, 'aria-labelledby', this.ariaLabelledby);
        }
        if (this.ariaDescribedby) {
            this.renderer.setAttribute(nativeElement, 'aria-describedby', this.ariaDescribedby);
        }
    }
    ngOnInit() {
        this.updateComponentProperties();
    }
    ngOnChanges() {
        this.updateComponentProperties();
    }
    ngAfterViewInit() {
        this.el.nativeElement.addEventListener('wizard-change', this.handleWizardchange);
        this.el.nativeElement.addEventListener('wizard-complete', this.handleWizardcomplete);
    }
    ngOnDestroy() {
        this.el.nativeElement.removeEventListener('wizard-change', this.handleWizardchange);
        this.el.nativeElement.removeEventListener('wizard-complete', this.handleWizardcomplete);
    }
}
WizardComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
WizardComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: WizardComponent, selector: "fabric-wizard", inputs: { ordered: "ordered", disableOnComplete: "disableOnComplete", currentIndex: "currentIndex", ariaLabelledby: "ariaLabelledby", ariaDescribedby: "ariaDescribedby" }, outputs: { wizardchange: "wizardchange", wizardcomplete: "wizardcomplete" }, usesOnChanges: true, ngImport: i0, template: `
    <ng-content></ng-content>
  `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fabric-wizard',
                    template: `
    <ng-content></ng-content>
  `,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }]; }, propDecorators: { ordered: [{
                type: Input
            }], disableOnComplete: [{
                type: Input
            }], currentIndex: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], ariaDescribedby: [{
                type: Input
            }], wizardchange: [{
                type: Output
            }], wizardcomplete: [{
                type: Output
            }] } });

/**
 * @description
 * WizardProxyModule provides an Angular wrapper for the Fabric Wizard web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard>
 *   <fabric-wizard-step slot="step">Step 1</fabric-wizard-step>
 *   <fabric-wizard-step slot="step">Step 2</fabric-wizard-step>
 *   <fabric-wizard-step slot="step">Step 3</fabric-wizard-step>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 1 Content</h3>
 *     <p>This is the content for step 1.</p>
 *   </fabric-wizard-panel>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 2 Content</h3>
 *     <p>This is the content for step 2.</p>
 *   </fabric-wizard-panel>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 3 Content</h3>
 *     <p>This is the content for step 3.</p>
 *   </fabric-wizard-panel>
 * </fabric-wizard>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard
 *   [ordered]="true"
 *   [disableOnComplete]="true"
 *   [currentIndex]="currentStepIndex"
 *   [ariaLabelledby]="'wizard-title'"
 *   [ariaDescribedby]="'wizard-description'"
 *   (wizardchange)="onWizardChange($event)"
 *   (wizardcomplete)="onWizardComplete($event)">
 *   <!-- Wizard steps and panels -->
 * </fabric-wizard>
 * ```
 *
 * ## Available Inputs
 * - `ordered: boolean` - Whether to show step numbers (default: false)
 * - `disableOnComplete: boolean` - Whether to disable steps after completion (default: false)
 * - `currentIndex: number` - The index of the currently active step (default: 0)
 * - `ariaLabelledby: string` - ID of an element that labels the wizard for accessibility
 * - `ariaDescribedby: string` - ID of an element that describes the wizard for accessibility
 *
 * ## Available Events
 * - `wizardchange` - Emitted when the active step changes
 *   - Example: `<fabric-wizard (wizardchange)="onStepChange($event)"></fabric-wizard>`
 * - `wizardcomplete` - Emitted when all steps are completed
 *   - Example: `<fabric-wizard (wizardcomplete)="onComplete($event)"></fabric-wizard>`
 *
 * ## Available Outputs
 * - `wizardchange: EventEmitter<any>` - Emitted when the active step changes
 * - `wizardcomplete: EventEmitter<any>` - Emitted when all steps are completed
 *
 * ## Available Slots
 * - `step` - For wizard step components
 * - `panel` - For wizard panel components
 *
 * @example
 * ```js
 * // In your module:
 * import { WizardProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { WizardStepProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { WizardPanelProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [
 *     WizardProxyModule,
 *     WizardStepProxyModule,
 *     WizardPanelProxyModule,
 *     ButtonProxyModule
 *   ]
 * })
 * export class YourModule { }
 * ```
 *
 * // In your component:
 * ```js
 * \@Component({
 *   selector: 'app-wizard-example',
 *   template: `
 *     <div id="wizard-title" class="sr-only">Configuration Wizard</div>
 *     <div id="wizard-description" class="sr-only">Complete all steps to configure your application</div>
 *
 *     <fabric-wizard
 *       [ordered]="true"
 *       [currentIndex]="currentStep"
 *       [ariaLabelledby]="'wizard-title'"
 *       [ariaDescribedby]="'wizard-description'"
 *       (wizardchange)="onStepChange($event)"
 *       (wizardcomplete)="onWizardComplete($event)">
 *
 *       <fabric-wizard-step slot="step">Account</fabric-wizard-step>
 *       <fabric-wizard-step slot="step">Preferences</fabric-wizard-step>
 *       <fabric-wizard-step slot="step">Review</fabric-wizard-step>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Account Setup</h3>
 *         <!-- Account form fields -->
 *         <div class="buttons">
 *           <fabric-button (click)="nextStep()">Next</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Preferences</h3>
 *         <!-- Preference options -->
 *         <div class="buttons">
 *           <fabric-button (click)="prevStep()">Back</fabric-button>
 *           <fabric-button (click)="nextStep()" [appearance]="'primary'">Next</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Review</h3>
 *         <!-- Summary and review -->
 *         <div class="buttons">
 *           <fabric-button (click)="prevStep()">Back</fabric-button>
 *           <fabric-button (click)="complete()" [appearance]="'primary'">Complete</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *     </fabric-wizard>
 *   `
 * })
 * export class WizardExampleComponent {
 *   currentStep = 0;
 *
 *   nextStep() {
 *     this.currentStep++;
 *   }
 *
 *   prevStep() {
 *     this.currentStep--;
 *   }
 *
 *   onStepChange(event: any) {
 *     console.log('Step changed:', event);
 *   }
 *
 *   onWizardComplete(event: any) {
 *     console.log('Wizard completed!');
 *   }
 *
 *   complete() {
 *     // Handle completion actions
 *     alert('Wizard completed successfully!');
 *   }
 * }
 * ```
 */
class WizardProxyModule {
    constructor() {
        WizardDefinition.define();
    }
    ngDoBootstrap(appRef) { }
}
WizardProxyModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardProxyModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
WizardProxyModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: WizardProxyModule, declarations: [WizardComponent], imports: [CommonModule], exports: [WizardComponent] });
WizardProxyModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardProxyModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: WizardProxyModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WizardComponent],
                    imports: [CommonModule],
                    exports: [WizardComponent]
                }]
        }], ctorParameters: function () { return []; } });

/*
 * Public API Surface of fabric-wrappers
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccordionMenuComponent, AccordionMenuPanelComponent, AccordionMenuPanelProxyModule, AccordionMenuProxyModule, ButtonComponent, ButtonProxyModule, CardComponent, CardFooterComponent, CardFooterProxyModule, CardHeaderComponent, CardHeaderProxyModule, CardPreviewComponent, CardPreviewProxyModule, CardProxyModule, CarouselComponent, CarouselProxyModule, FilterPillComponent, FilterPillProxyModule, LoadingButtonComponent, LoadingButtonProxyModule, MenuButtonComponent, MenuButtonProxyModule, MenuComponent, MenuItemComponent, MenuItemProxyModule, MenuListComponent, MenuListProxyModule, MenuProxyModule, MessageBarComponent, MessageBarProxyModule, MultiViewComponent, MultiViewControllerComponent, MultiViewControllerProxyModule, MultiViewGroupComponent, MultiViewGroupProxyModule, MultiViewProxyModule, PopoverComponent, PopoverProxyModule, SvgIconComponent, SvgIconProxyModule, TableCellComponent, TableCellProxyModule, TableComponent, TableProxyModule, TagComponent, TagProxyModule, TeachingBubbleComponent, TeachingBubbleProxyModule, TooltipComponent, TooltipProxyModule, WizardComponent, WizardPanelComponent, WizardPanelProxyModule, WizardProxyModule, WizardStepComponent, WizardStepProxyModule };
//# sourceMappingURL=fabric-msft-fabric-angular.mjs.map
