import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./filter-pill.component";
import * as i2 from "@angular/common";
/**
 * @description
 * FilterPillProxyModule provides an Angular wrapper for the Fabric FilterPill web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-filter-pill>Filter Label</fabric-filter-pill>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-filter-pill
 *   [appearance]="'primary'"
 *   [shape]="'rounded'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   [selected]="true"
 *   (click)="handleClick($event)">
 *   Filter Label
 * </fabric-filter-pill>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-filter-pill>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Filter Label
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-filter-pill>
 * ```
 *
 * ## Available Inputs
 * - `appearance: FilterPillAppearance` - Visual style of the filter pill: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `shape: FilterPillShape` - Shape of the filter pill: 'rounded' | 'circular' | 'square' (default: 'rounded')
 * - `size: FilterPillSize` - Size of the filter pill: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the filter pill is disabled (default: false)
 * - `selected: boolean` - Whether the filter pill is selected (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the filter pill is clicked
 *   - Example: `<fabric-filter-pill (click)="onFilterClick($event)">Filter</fabric-filter-pill>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the filter pill text
 * - `endIcon` - Icon displayed after the filter pill text
 * - Default slot - Main filter pill text content
 *
 * @example
 * // In your module:
 * import { FilterPillProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [FilterPillProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-filter-pill
 *   [appearance]="'primary'"
 *   [selected]="isSelected"
 *   (click)="toggleFilter()">
 *   Category
 * </fabric-filter-pill>
 */
export declare class FilterPillProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterPillProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<FilterPillProxyModule, [typeof i1.FilterPillComponent], [typeof i2.CommonModule], [typeof i1.FilterPillComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<FilterPillProxyModule>;
}
//# sourceMappingURL=filter-pill.module.d.ts.map