/**
 * @description
 * LoadingButtonProxyModule provides an Angular wrapper for the Fabric LoadingButton web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-loading-button>Click me</fabric-loading-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-loading-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [shape]="'rounded'"
 *   [disabled]="false"
 *   [loading]="isLoading"
 *   (click)="handleClick($event)">
 *   Click me
 * </fabric-loading-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-loading-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Button text
 *   <span slot="endIcon"><svg>...</svg></span>
 * </fabric-loading-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: ButtonAppearance` - Visual style of the button: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: ButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `shape: ButtonShape` - Shape of the button: 'rounded' | 'circular' | 'square' (default: 'rounded')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `loading: boolean` - Whether the button is in loading state (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the button is clicked
 *   - Example: `<fabric-loading-button (click)="onClick($event)">Click me</fabric-loading-button>`
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Main button text content
 *
 * @example
 * // In your module:
 * import { LoadingButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [LoadingButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-loading-button
 *   [appearance]="'primary'"
 *   [loading]="isSubmitting"
 *   (click)="submitForm()">
 *   Submit
 * </fabric-loading-button>
 */
import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./loading-button.component";
import * as i2 from "@angular/common";
export declare class LoadingButtonProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<LoadingButtonProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<LoadingButtonProxyModule, [typeof i1.LoadingButtonComponent], [typeof i2.CommonModule], [typeof i1.LoadingButtonComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<LoadingButtonProxyModule>;
}
//# sourceMappingURL=loading-button.module.d.ts.map