import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./menu-button.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MenuButtonProxyModule provides an Angular wrapper for the Fabric MenuButton web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-button>
 *   Menu Button
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-button
 *   [appearance]="'primary'"
 *   [size]="'medium'"
 *   [disabled]="false"
 *   [expanded]="isExpanded"
 *   (click)="handleClick($event)"
 *   (toggle)="handleToggle($event)">
 *   Menu Button
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu-button>
 *   <span slot="startIcon"><svg>...</svg></span>
 *   Menu Button Text
 *   <span slot="endIcon"><svg>...</svg></span>
 *
 *   <fabric-menu>
 *     <fabric-menu-item>Option 1</fabric-menu-item>
 *     <fabric-menu-item>Option 2</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 * ```
 *
 * ## Available Inputs
 * - `appearance: MenuButtonAppearance` - Visual style: 'primary' | 'secondary' | 'subtle' (default: 'primary')
 * - `size: MenuButtonSize` - Size of the button: 'small' | 'medium' | 'large' (default: 'medium')
 * - `disabled: boolean` - Whether the button is disabled (default: false)
 * - `expanded: boolean` - Whether the associated menu is expanded (default: false)
 * - `iconOnly: boolean` - Whether the button only shows an icon (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the menu button is clicked
 *   - Example: `<fabric-menu-button (click)="onClick($event)">Menu</fabric-menu-button>`
 * - `toggle` - Emitted when the menu is toggled open or closed
 *   - Example: `<fabric-menu-button (toggle)="onToggle($event)">Menu</fabric-menu-button>`
 *
 * ## Available Outputs
 * - `click: EventEmitter<any>` - Emitted when the menu button is clicked
 * - `toggle: EventEmitter<any>` - Emitted when the menu is toggled open or closed
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the button text
 * - `endIcon` - Icon displayed after the button text
 * - Default slot - Contains the button text and the menu element
 *
 * @example
 * // In your module:
 * import { MenuButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MenuButtonProxyModule,
 *     MenuProxyModule,
 *     MenuItemProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-button
 *   [appearance]="'primary'"
 *   [expanded]="isMenuOpen"
 *   (toggle)="toggleMenu($event)">
 *   Settings
 *   <fabric-menu>
 *     <fabric-menu-item (click)="onSelectOption('profile')">Profile</fabric-menu-item>
 *     <fabric-menu-item (click)="onSelectOption('preferences')">Preferences</fabric-menu-item>
 *     <fabric-menu-item (click)="onSelectOption('logout')">Logout</fabric-menu-item>
 *   </fabric-menu>
 * </fabric-menu-button>
 */
export declare class MenuButtonProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuButtonProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MenuButtonProxyModule, [typeof i1.MenuButtonComponent], [typeof i2.CommonModule], [typeof i1.MenuButtonComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MenuButtonProxyModule>;
}
//# sourceMappingURL=menu-button.module.d.ts.map