import { ElementRef, EventEmitter, NgZone, Renderer2, OnInit, OnChanges, AfterViewInit, OnDestroy } from '@angular/core';
import { MenuItemRole } from '@fabric-msft/fabric-web';
import * as i0 from "@angular/core";
/**
 * Angular wrapper component for the Fabric Menu Item web component.
 * Represents an interactive menu item with support for various roles and states.
 */
export declare class MenuItemComponent implements OnInit, OnChanges, AfterViewInit, OnDestroy {
    private readonly el;
    private readonly renderer;
    private readonly ngZone;
    /**
     * Reference to NgZone for managing event handling
     */
    readonly zone: NgZone;
    /**
     * Whether the menu item is disabled
     */
    disabled?: boolean;
    /**
     * The ARIA role of the menu item
     */
    role?: MenuItemRole;
    /**
     * Whether the menu item is checked (for checkable menu items)
     */
    checked: boolean;
    /**
     * Whether the menu item is hidden
     */
    hidden?: boolean;
    /**
     * Emits when the menu item state changes
     */
    readonly change: EventEmitter<CustomEvent<any>>;
    constructor(el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    /**
     * Updates the component's properties on the native element
     */
    private updateComponentProperties;
    /**
     * Handles menu item state changes
     */
    private handleChange;
    /**
     * Initializes component properties
     */
    ngOnInit(): void;
    /**
     * Updates properties when inputs change
     */
    ngOnChanges(): void;
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuItemComponent, "fabric-menu-item", never, { "disabled": "disabled"; "role": "role"; "checked": "checked"; "hidden": "hidden"; }, { "change": "change"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=menu-item.component.d.ts.map