import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./menu-item.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MenuItemProxyModule provides an Angular wrapper for the Fabric MenuItem web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-item>Menu Item Text</fabric-menu-item>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-item
 *   [disabled]="false"
 *   [selected]="false"
 *   [checked]="false"
 *   (click)="handleClick($event)">
 *   Menu Item Text
 * </fabric-menu-item>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu-item>
 *   <!-- Optional icon before text -->
 *   <span slot="startIcon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Menu item text -->
 *   Menu Item Text
 *
 *   <!-- Optional icon after text -->
 *   <span slot="endIcon">
 *     <svg>...</svg>
 *   </span>
 * </fabric-menu-item>
 * ```
 *
 * ## Available Inputs
 * - `disabled: boolean` - Whether the menu item is disabled (default: false)
 * - `selected: boolean` - Whether the menu item is selected (default: false)
 * - `checked: boolean` - Whether the menu item is checked, for checkbox/radio variants (default: false)
 *
 * ## Available Events
 * - `click` - Emitted when the menu item is clicked
 *   - Example: `<fabric-menu-item (click)="onMenuItemClick($event)">Item</fabric-menu-item>`
 * - `select` - Emitted when the menu item is selected
 *   - Example: `<fabric-menu-item (select)="onMenuItemSelect($event)">Item</fabric-menu-item>`
 *
 * ## Available Outputs
 * - `click: EventEmitter<any>` - Emitted when the menu item is clicked
 * - `select: EventEmitter<any>` - Emitted when the menu item is selected
 *
 * ## Available Slots
 * - `startIcon` - Icon displayed before the menu item text
 * - `endIcon` - Icon displayed after the menu item text
 * - Default slot - Main menu item text content
 *
 * @example
 * // In your module:
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuItemProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-list>
 *   <fabric-menu-item
 *     [disabled]="isDisabled"
 *     (click)="handleItemClick()">
 *     Settings
 *   </fabric-menu-item>
 *   <fabric-menu-item
 *     [checked]="isChecked"
 *     (click)="toggleOption()">
 *     Enable feature
 *   </fabric-menu-item>
 * </fabric-menu-list>
 */
export declare class MenuItemProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuItemProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MenuItemProxyModule, [typeof i1.MenuItemComponent], [typeof i2.CommonModule], [typeof i1.MenuItemComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MenuItemProxyModule>;
}
//# sourceMappingURL=menu-item.module.d.ts.map