import { ElementRef, EventEmitter, NgZone, Renderer2, AfterViewInit, OnDestroy } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Angular wrapper component for the Fabric Menu List web component.
 * Provides a list container for menu items with keyboard navigation and accessibility support.
 */
export declare class MenuListComponent implements AfterViewInit, OnDestroy {
    private readonly el;
    private readonly renderer;
    private readonly ngZone;
    /**
     * Reference to NgZone for managing event handling
     */
    readonly zone: NgZone;
    /**
     * Emits when a menu item selection changes
     */
    readonly change: EventEmitter<CustomEvent<any>>;
    /**
     * Emits when a keyboard event occurs on the menu list
     */
    readonly keydown: EventEmitter<CustomEvent<any>>;
    /**
     * Emits when the expanded state of the menu list changes
     */
    readonly expandedChange: EventEmitter<CustomEvent<any>>;
    constructor(el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    /**
     * Handles menu item selection changes
     */
    private handleChange;
    /**
     * Handles keyboard events
     */
    private handleKeydown;
    /**
     * Handles expanded state changes
     */
    private handleExpandedChange;
    /**
     * Sets up event listeners after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Cleans up event listeners on component destruction
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuListComponent, "fabric-menu-list", never, {}, { "change": "change"; "keydown": "keydown"; "expandedChange": "expandedChange"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=menu-list.component.d.ts.map