import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./menu-list.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MenuListProxyModule provides an Angular wrapper for the Fabric MenuList web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu-list>
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu-list>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu-list
 *   [disabled]="false"
 *   [appearance]="'subtle'"
 *   (selectionChange)="handleSelectionChange($event)">
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu-list>
 * ```
 *
 * ## Available Inputs
 * - `disabled: boolean` - Whether the menu list is disabled (default: false)
 * - `appearance: MenuListAppearance` - Visual style of the menu list: 'subtle' | 'default' (default: 'default')
 *
 * ## Available Events
 * - `selectionChange` - Emitted when an item is selected from the menu list
 *   - Example: `<fabric-menu-list (selectionChange)="onSelectionChange($event)"></fabric-menu-list>`
 *
 * ## Available Outputs
 * - `selectionChange: EventEmitter<any>` - Emitted when menu item selection changes
 *
 * ## Available Slots
 * - Default slot - Content for menu items
 *
 * @example
 * // In your module:
 * import { MenuListProxyModule, MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuListProxyModule, MenuItemProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu-list
 *   [appearance]="menuAppearance"
 *   (selectionChange)="handleMenuSelection($event)">
 *   <fabric-menu-item *ngFor="let item of menuItems">
 *     {{item.label}}
 *   </fabric-menu-item>
 * </fabric-menu-list>
 */
export declare class MenuListProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuListProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MenuListProxyModule, [typeof i1.MenuListComponent], [typeof i2.CommonModule], [typeof i1.MenuListComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MenuListProxyModule>;
}
//# sourceMappingURL=menu-list.module.d.ts.map