/**
 * @description
 * MenuProxyModule provides an Angular wrapper for the Fabric Menu web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-menu>
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-menu
 *   [open]="isMenuOpen"
 *   [anchor]="'bottom-start'"
 *   [positioning]="'fixed'"
 *   (openChange)="handleOpenChange($event)">
 *   <fabric-menu-item>Item 1</fabric-menu-item>
 *   <fabric-menu-item>Item 2</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-menu>
 *   <!-- Trigger element (usually a button) -->
 *   <fabric-button slot="trigger">
 *     Open Menu
 *   </fabric-button>
 *
 *   <!-- Menu items -->
 *   <fabric-menu-item>Option 1</fabric-menu-item>
 *   <fabric-menu-item>Option 2</fabric-menu-item>
 *   <fabric-menu-item disabled>Option 3 (Disabled)</fabric-menu-item>
 *
 *   <!-- Divider -->
 *   <fabric-divider></fabric-divider>
 *
 *   <!-- More menu items -->
 *   <fabric-menu-item>Option 4</fabric-menu-item>
 * </fabric-menu>
 * ```
 *
 * ## Available Inputs
 * - `open: boolean` - Whether the menu is open (default: false)
 * - `anchor: MenuAnchor` - How to position the menu relative to its anchor: 'top-start' | 'top' | 'top-end' | 'bottom-start' | 'bottom' | 'bottom-end' | 'start-top' | 'start' | 'start-bottom' | 'end-top' | 'end' | 'end-bottom' (default: 'bottom-start')
 * - `positioning: MenuPositioning` - How to position the menu: 'fixed' | 'absolute' | 'auto' (default: 'auto')
 * - `offset: number` - Distance in pixels between the menu and its anchor (default: 0)
 * - `autoFocus: boolean` - Whether to automatically focus the first item when opened (default: true)
 *
 * ## Available Events
 * - `openChange` - Emitted when the menu's open state changes
 *   - Example: `<fabric-menu (openChange)="onOpenChange($event)"></fabric-menu>`
 * - `select` - Emitted when a menu item is selected
 *   - Example: `<fabric-menu (select)="onMenuItemSelect($event)"></fabric-menu>`
 *
 * ## Available Outputs
 * - `openChange: EventEmitter<boolean>` - Emitted when the menu's open state changes
 * - `select: EventEmitter<any>` - Emitted when a menu item is selected
 *
 * ## Available Slots
 * - `trigger` - Content that serves as the trigger for the menu
 * - Default slot - Menu items (usually `<fabric-menu-item>` elements)
 *
 * @example
 * // In your module:
 * import { MenuProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MenuItemProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MenuProxyModule, MenuItemProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-menu
 *   [open]="isMenuOpen"
 *   (openChange)="handleOpenChange($event)"
 *   (select)="handleMenuSelect($event)">
 *   <fabric-button slot="trigger">Open Menu</fabric-button>
 *   <fabric-menu-item>Profile</fabric-menu-item>
 *   <fabric-menu-item>Settings</fabric-menu-item>
 *   <fabric-menu-item>Logout</fabric-menu-item>
 * </fabric-menu>
 */
import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./menu.component";
import * as i2 from "@angular/common";
export declare class MenuProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MenuProxyModule, [typeof i1.MenuComponent], [typeof i2.CommonModule], [typeof i1.MenuComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MenuProxyModule>;
}
//# sourceMappingURL=menu.module.d.ts.map