import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./message-bar.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MessageBarProxyModule provides an Angular wrapper for the Fabric MessageBar web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-message-bar>
 *   This is a message bar notification
 * </fabric-message-bar>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-message-bar
 *   [intent]="'info'"
 *   [dismissible]="true"
 *   (dismiss)="handleDismiss($event)">
 *   This is an informational message with a dismiss button
 * </fabric-message-bar>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-message-bar [intent]="'warning'">
 *   <!-- Custom icon -->
 *   <span slot="icon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Message content -->
 *   <span>Warning message content</span>
 *
 *   <!-- Action buttons/links -->
 *   <span slot="action">
 *     <fabric-button>Action</fabric-button>
 *   </span>
 * </fabric-message-bar>
 * ```
 *
 * ## Available Inputs
 * - `intent: MessageBarIntent` - Type of message: 'info' | 'success' | 'warning' | 'error' (default: 'info')
 * - `dismissible: boolean` - Whether the message bar can be dismissed (default: false)
 *
 * ## Available Events
 * - `dismiss` - Emitted when the message bar is dismissed (clicked on dismiss button)
 *   - Example: `<fabric-message-bar [dismissible]="true" (dismiss)="onDismiss()">Message</fabric-message-bar>`
 *
 * ## Available Outputs
 * - `dismiss: EventEmitter<any>` - Emitted when the message bar is dismissed
 *
 * ## Available Slots
 * - `icon` - Custom icon to display
 * - `action` - Area for action buttons or links
 * - Default slot - Main message content
 *
 * @example
 * // In your module:
 * import { MessageBarProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [MessageBarProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-message-bar
 *   [intent]="'success'"
 *   [dismissible]="true"
 *   (dismiss)="onMessageDismiss()">
 *   Operation completed successfully!
 *   <span slot="action">
 *     <a href="#">View details</a>
 *   </span>
 * </fabric-message-bar>
 */
export declare class MessageBarProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MessageBarProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MessageBarProxyModule, [typeof i1.MessageBarComponent], [typeof i2.CommonModule], [typeof i1.MessageBarComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MessageBarProxyModule>;
}
//# sourceMappingURL=message-bar.module.d.ts.map