import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./multi-view-controller.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MultiViewControllerProxyModule provides an Angular wrapper for the Fabric MultiViewController web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view-controller>
 *   <!-- Controller content -->
 * </fabric-multi-view-controller>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view-controller
 *   [activeIndex]="0"
 *   [disabled]="false"
 *   (activeIndexChange)="handleViewChange($event)">
 *   <!-- Controller content -->
 * </fabric-multi-view-controller>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-multi-view-controller>
 *   <span slot="previous">Previous</span>
 *   <span slot="next">Next</span>
 *   <span slot="indicator">
 *     <!-- Custom indicators -->
 *   </span>
 * </fabric-multi-view-controller>
 * ```
 *
 * ## Within MultiView Component
 * ```html
 * <fabric-multi-view>
 *   <fabric-multi-view-controller slot="controller">
 *     <!-- Controller content -->
 *   </fabric-multi-view-controller>
 *
 *   <fabric-multi-view-group>
 *     <div>View 1 Content</div>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group>
 *     <div>View 2 Content</div>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## Available Inputs
 * - `activeIndex: number` - The zero-based index of the currently active view (default: 0)
 * - `disabled: boolean` - Whether the controller is disabled (default: false)
 *
 * ## Available Events
 * - `activeIndexChange` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view-controller (activeIndexChange)="onViewChange($event)"></fabric-multi-view-controller>`
 *
 * ## Available Outputs
 * - `activeIndexChange: EventEmitter<number>` - Emitted when the active view changes
 *
 * ## Available Slots
 * - `previous` - Content for the previous button/control
 * - `next` - Content for the next button/control
 * - `indicator` - Content for view indicators
 *
 * @example
 * // In your module:
 * import { MultiViewControllerProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewControllerProxyModule,
 *     MultiViewProxyModule,
 *     MultiViewGroupProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view>
 *   <fabric-multi-view-controller
 *     slot="controller"
 *     [activeIndex]="currentViewIndex"
 *     (activeIndexChange)="onViewChange($event)">
 *   </fabric-multi-view-controller>
 *
 *   <fabric-multi-view-group *ngFor="let view of views">
 *     <div>{{view.content}}</div>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 */
export declare class MultiViewControllerProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiViewControllerProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MultiViewControllerProxyModule, [typeof i1.MultiViewControllerComponent], [typeof i2.CommonModule], [typeof i1.MultiViewControllerComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MultiViewControllerProxyModule>;
}
//# sourceMappingURL=multi-view-controller.module.d.ts.map