import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./multi-view-group.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MultiViewGroupProxyModule provides an Angular wrapper for the Fabric MultiViewGroup web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view-group>
 *   <!-- Multi-view content -->
 * </fabric-multi-view-group>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view-group
 *   [active]="currentViewId"
 *   [disabled]="false">
 *   <!-- Multi-view content -->
 * </fabric-multi-view-group>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-multi-view-group>
 *   <fabric-multi-view id="view1">View 1 Content</fabric-multi-view>
 *   <fabric-multi-view id="view2">View 2 Content</fabric-multi-view>
 *   <fabric-multi-view id="view3">View 3 Content</fabric-multi-view>
 * </fabric-multi-view-group>
 * ```
 *
 * ## Available Inputs
 * - `active: string` - ID of the currently active view (default: first view's ID)
 * - `disabled: boolean` - Whether the multi-view group is disabled (default: false)
 *
 * ## Available Events
 * - `change` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view-group (change)="onViewChange($event)"></fabric-multi-view-group>`
 *
 * ## Available Outputs
 * - `change: EventEmitter<any>` - Emitted when the active view changes
 *
 * ## Available Slots
 * - Default slot - Container for fabric-multi-view components
 *
 * @example
 * // In your module:
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewGroupProxyModule,
 *     MultiViewProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view-group
 *   [active]="activeViewId"
 *   (change)="onViewChange($event)">
 *   <fabric-multi-view id="summary">Summary View</fabric-multi-view>
 *   <fabric-multi-view id="details">Details View</fabric-multi-view>
 *   <fabric-multi-view id="settings">Settings View</fabric-multi-view>
 * </fabric-multi-view-group>
 */
export declare class MultiViewGroupProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiViewGroupProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MultiViewGroupProxyModule, [typeof i1.MultiViewGroupComponent], [typeof i2.CommonModule], [typeof i1.MultiViewGroupComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MultiViewGroupProxyModule>;
}
//# sourceMappingURL=multi-view-group.module.d.ts.map