import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./multi-view.component";
import * as i2 from "@angular/common";
/**
 * @description
 * MultiViewProxyModule provides an Angular wrapper for the Fabric MultiView web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-multi-view>
 *   <fabric-multi-view-controller></fabric-multi-view-controller>
 *   <fabric-multi-view-group>
 *     <!-- View content -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-multi-view
 *   [activeId]="'view1'"
 *   (viewChange)="handleViewChange($event)">
 *   <fabric-multi-view-controller>
 *     <!-- Controller content -->
 *   </fabric-multi-view-controller>
 *   <fabric-multi-view-group>
 *     <!-- View content -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## With Controller and Groups
 * ```html
 * <fabric-multi-view [activeId]="activeViewId">
 *   <!-- Navigation controller -->
 *   <fabric-multi-view-controller>
 *     <button id="view1">View 1</button>
 *     <button id="view2">View 2</button>
 *     <button id="view3">View 3</button>
 *   </fabric-multi-view-controller>
 *
 *   <!-- Content groups -->
 *   <fabric-multi-view-group id="view1">
 *     <h2>View 1 Content</h2>
 *     <p>This is the content for view 1</p>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group id="view2">
 *     <h2>View 2 Content</h2>
 *     <p>This is the content for view 2</p>
 *   </fabric-multi-view-group>
 *
 *   <fabric-multi-view-group id="view3">
 *     <h2>View 3 Content</h2>
 *     <p>This is the content for view 3</p>
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 * ```
 *
 * ## Available Inputs
 * - `activeId: string` - ID of the currently active view group (default: first view group's ID)
 *
 * ## Available Events
 * - `viewChange` - Emitted when the active view changes
 *   - Example: `<fabric-multi-view (viewChange)="onViewChange($event)"></fabric-multi-view>`
 *
 * ## Available Outputs
 * - `viewChange: EventEmitter<string>` - Emitted when the active view changes, with the new active view ID
 *
 * ## Component Composition
 * MultiView is composed of the following components:
 * - `fabric-multi-view` - The root container component
 * - `fabric-multi-view-controller` - Contains navigation controls for switching views
 * - `fabric-multi-view-group` - Individual view containers with unique IDs
 *
 * @example
 * // In your module:
 * import { MultiViewProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewControllerProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { MultiViewGroupProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [
 *     MultiViewProxyModule,
 *     MultiViewControllerProxyModule,
 *     MultiViewGroupProxyModule
 *   ]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-multi-view
 *   [activeId]="selectedViewId"
 *   (viewChange)="onViewChange($event)">
 *   <fabric-multi-view-controller>
 *     <!-- Navigation controls -->
 *   </fabric-multi-view-controller>
 *   <fabric-multi-view-group id="view1">
 *     <!-- Content for view 1 -->
 *   </fabric-multi-view-group>
 *   <fabric-multi-view-group id="view2">
 *     <!-- Content for view 2 -->
 *   </fabric-multi-view-group>
 * </fabric-multi-view>
 */
export declare class MultiViewProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiViewProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<MultiViewProxyModule, [typeof i1.MultiViewComponent], [typeof i2.CommonModule], [typeof i1.MultiViewComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<MultiViewProxyModule>;
}
//# sourceMappingURL=multi-view.module.d.ts.map