import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./popover.component";
import * as i2 from "@angular/common";
/**
 * @description
 * PopoverProxyModule provides an Angular wrapper for the Fabric Popover web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-popover>
 *   <button slot="trigger">Click me</button>
 *   <div>Popover content</div>
 * </fabric-popover>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-popover
 *   [open]="isPopoverOpen"
 *   [placement]="'top'"
 *   [beak]="true"
 *   [mode]="'auto'"
 *   (hide)="onPopoverHide($event)"
 *   (show)="onPopoverShow($event)">
 *   <button slot="trigger">Click me</button>
 *   <div>Popover content</div>
 * </fabric-popover>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-popover>
 *   <!-- Element that triggers the popover -->
 *   <button slot="trigger">Open popover</button>
 *
 *   <!-- Content inside the popover -->
 *   <div>
 *     <h3>Popover Title</h3>
 *     <p>Popover content</p>
 *     <fabric-button>Action</fabric-button>
 *   </div>
 * </fabric-popover>
 * ```
 *
 * ## Available Inputs
 * - `open: boolean` - Whether the popover is open (default: false)
 * - `beak: boolean` - Whether the popover has a visual beak/arrow pointer (default: false)
 * - `nonClickable: boolean` - Indicates if the popover anchor is not clickable (default: false)
 * - `size: PopoverSize` - Size of the popover: 'small' | 'medium' | 'large' (default: 'medium')
 * - `mode: PopoverMode` - Behavior mode: 'auto' | 'manual' (default: 'manual')
 * - `position: PositioningShorthandValues` - Position of the popover relative to its anchor
 * - `targetId: string` - ID of the target element to anchor the popover to
 * - `repositionMode: PopoverRepositionMode` - How the popover repositions: 'flip' | 'none' (default: 'flip')
 * - `overflowBoundarySelector: string` - CSS selector for the overflow boundary container
 * - `ariaLabel: string` - ARIA label for accessibility
 * - `transitionDuration: number` - Duration of popover transition in ms (default: 100)
 * - `transitionDelay: number` - Delay before popover transition in ms (default: 0)
 *
 * ## Available Events
 * - `hide` - Emitted when the popover is hidden
 *   - Example: `<fabric-popover (hide)="onHide($event)"></fabric-popover>`
 * - `show` - Emitted when the popover is shown
 *   - Example: `<fabric-popover (show)="onShow($event)"></fabric-popover>`
 * - `toggle` - Emitted when the popover visibility is toggled
 *   - Example: `<fabric-popover (toggle)="onToggle($event)"></fabric-popover>`
 * - `mouseEnter` - Emitted when mouse enters the popover
 *   - Example: `<fabric-popover (mouseEnter)="onMouseEnter($event)"></fabric-popover>`
 * - `mouseLeave` - Emitted when mouse leaves the popover
 *   - Example: `<fabric-popover (mouseLeave)="onMouseLeave($event)"></fabric-popover>`
 *
 * ## Available Outputs
 * - `hide: EventEmitter<any>` - Emitted when the popover is hidden
 * - `show: EventEmitter<any>` - Emitted when the popover is shown
 * - `toggle: EventEmitter<any>` - Emitted when the popover visibility is toggled
 * - `mouseEnter: EventEmitter<any>` - Emitted when mouse enters the popover
 * - `mouseLeave: EventEmitter<any>` - Emitted when mouse leaves the popover
 *
 * ## Available Slots
 * - `trigger` - Element that triggers the popover
 * - Default slot - Content to display in the popover
 *
 * @example
 * // In your module:
 * import { PopoverProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [PopoverProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-popover
 *   [open]="isPopoverVisible"
 *   [position]="'top'"
 *   [beak]="true"
 *   (show)="onShowPopover()"
 *   (hide)="onHidePopover()">
 *   <fabric-button slot="trigger">Show info</fabric-button>
 *   <div>
 *     <h3>Additional Information</h3>
 *     <p>This provides more context about the feature.</p>
 *   </div>
 * </fabric-popover>
 */
export declare class PopoverProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PopoverProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<PopoverProxyModule, [typeof i1.PopoverComponent], [typeof i2.CommonModule], [typeof i1.PopoverComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<PopoverProxyModule>;
}
//# sourceMappingURL=popover.module.d.ts.map