import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./svg-icon.component";
import * as i2 from "@angular/common";
/**
 * @description
 * SvgIconProxyModule provides an Angular wrapper for the Fabric SvgIcon web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-svg-icon path="path/to/icons.svg" name="icon-name"></fabric-svg-icon>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-svg-icon
 *   [path]="'assets/icons/icons.svg'"
 *   [name]="'settings'"
 *   [size]="'24'"
 *   [ariaLabel]="'Settings'"
 *   [ariaHidden]="'false'"
 *   (error)="handleIconError($event)">
 * </fabric-svg-icon>
 * ```
 *
 * ## Available Inputs
 * - `name: string` - The name of the SVG to use from the SVG sprite
 * - `size: string` - The size of the icon in pixels: '12' | '16' | '20' | '24' | '28' | '32' | '48' (default: '20')
 * - `path: string` - Path to SVG file (can be standalone SVG or SVG sprite)
 * - `ariaHidden: string` - Whether the icon is hidden from screen readers (default: 'true')
 * - `focusable: string` - Whether the icon is focusable (default: 'false')
 * - `role: string` - The accessibility role of the icon (default: '')
 * - `ariaLabel: string` - Optional label for the icon for accessibility
 *
 * ## Available Events
 * - `error` - Emitted when the icon fails to load
 *   - Example: `<fabric-svg-icon (error)="onIconError($event)"></fabric-svg-icon>`
 *
 * @example
 * // In your module:
 * import { SvgIconProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [SvgIconProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-svg-icon
 *   [path]="'assets/icons/icons.svg'"
 *   [name]="'user'"
 *   [size]="'24'"
 *   [ariaLabel]="'User profile'">
 * </fabric-svg-icon>
 */
export declare class SvgIconProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SvgIconProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<SvgIconProxyModule, [typeof i1.SvgIconComponent], [typeof i2.CommonModule], [typeof i1.SvgIconComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<SvgIconProxyModule>;
}
//# sourceMappingURL=svg-icon.module.d.ts.map