import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./table.component";
import * as i2 from "@angular/common";
/**
 * @description
 * TableProxyModule provides an Angular wrapper for the Fabric Table web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-table>
 *   <!-- Table content -->
 * </fabric-table>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-table [sortable]="true">
 *   <!-- Table content with sortable columns -->
 * </fabric-table>
 * ```
 *
 * ## With Content
 * ```html
 * <fabric-table [sortable]="true">
 *   <tr>
 *     <th>Name</th>
 *     <th>Email</th>
 *     <th>Role</th>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>John Doe</fabric-table-cell>
 *     <fabric-table-cell>john.doe@example.com</fabric-table-cell>
 *     <fabric-table-cell>Admin</fabric-table-cell>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>Jane Smith</fabric-table-cell>
 *     <fabric-table-cell>jane.smith@example.com</fabric-table-cell>
 *     <fabric-table-cell>User</fabric-table-cell>
 *   </tr>
 * </fabric-table>
 * ```
 *
 * ## Available Inputs
 * - `sortable: boolean` - Determines if the table has sortable columns (default: false)
 *
 * ## Available Slots
 * - Default slot - The content of the table, including headers and rows
 *
 * @example
 * // In your module:
 * import { TableProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { TableCellProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TableProxyModule, TableCellProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-table [sortable]="true">
 *   <tr>
 *     <th>Name</th>
 *     <th>Department</th>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>John Doe</fabric-table-cell>
 *     <fabric-table-cell>Engineering</fabric-table-cell>
 *   </tr>
 *   <tr>
 *     <fabric-table-cell>Jane Smith</fabric-table-cell>
 *     <fabric-table-cell>Design</fabric-table-cell>
 *   </tr>
 * </fabric-table>
 */
export declare class TableProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TableProxyModule, [typeof i1.TableComponent], [typeof i2.CommonModule], [typeof i1.TableComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TableProxyModule>;
}
//# sourceMappingURL=table.module.d.ts.map