import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./tag.component";
import * as i2 from "@angular/common";
/**
 * @description
 * TagProxyModule provides an Angular wrapper for the Fabric Tag web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-tag>Primary Text</fabric-tag>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-tag
 *   [dismissButton]="true"
 *   [disabled]="false"
 *   [size]="'medium'"
 *   [shape]="'rounded'"
 *   [appearance]="'filled'"
 *   (dismiss)="handleDismiss($event)">
 *   Tag Text
 * </fabric-tag>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-tag [dismissButton]="true">
 *   <!-- Leading icon (like SVG) -->
 *   <span slot="leadingIcon">
 *     <svg>...</svg>
 *   </span>
 *
 *   <!-- Main text -->
 *   <span slot="text">Primary Text</span>
 *
 *   <!-- Optional secondary text -->
 *   <span slot="textSecondary">Secondary Text</span>
 *
 *   <!-- Optional image/avatar -->
 *   <fluent-avatar slot="image" size="24" initials="JD"></fluent-avatar>
 * </fabric-tag>
 * ```
 *
 * ## Available Inputs
 * - `dismissButton: boolean` - Whether the tag shows a dismiss button (default: false)
 * - `disabled: boolean` - Whether the tag is disabled (default: false)
 * - `size: TagSize` - Size of the tag: 'extraSmall' | 'small' | 'medium' (default: 'medium')
 * - `shape: TagShape` - Shape of the tag: 'rounded' | 'circular' (default: 'rounded')
 * - `appearance: TagAppearance` - Visual style: 'filled' | 'outline' | 'brand' (default: 'filled')
 *
 * ## Available Events
 * - `dismiss` - Emitted when the tag is dismissed (clicked on dismiss button)
 *   - Example: `<fabric-tag [dismissButton]="true" (dismiss)="onTagDismiss()">Text</fabric-tag>`
 *
 * ## Available Outputs
 * - `dismiss: EventEmitter<any>` - Emitted when the dismiss button is clicked
 *
 * ## Available Slots
 * - `image` - For avatar or image content
 * - `leadingIcon` - For icon before the text
 * - `text` - Primary text content (required)
 * - `textSecondary` - Secondary text line
 * - `dismissIcon` - Custom dismiss icon (replaces default)
 *
 * @example
 * // In your module:
 * import { TagProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TagProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-tag
 *   [dismissButton]="true"
 *   [appearance]="'brand'"
 *   (dismiss)="onDismiss()">
 *   <span slot="text">Tag content</span>
 * </fabric-tag>
 */
export declare class TagProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TagProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TagProxyModule, [typeof i1.TagComponent], [typeof i2.CommonModule], [typeof i1.TagComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TagProxyModule>;
}
//# sourceMappingURL=tag.module.d.ts.map