import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./tooltip.component";
import * as i2 from "@angular/common";
/**
 * @description
 * TooltipProxyModule provides an Angular wrapper for the Fabric Tooltip web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-tooltip>
 *   <span slot="tooltip-trigger">Hover me</span>
 *   <span slot="tooltip-content">Tooltip content</span>
 * </fabric-tooltip>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-tooltip
 *   [position]="'top'"
 *   [open]="isTooltipOpen"
 *   [beak]="true"
 *   [targetId]="'custom-tooltip-id'"
 *   [transitionDuration]="200"
 *   [transitionDelay]="100"
 *   (hidePopover)="onHideTooltip($event)"
 *   (showPopover)="onShowTooltip($event)">
 *   <span slot="tooltip-trigger">Hover me</span>
 *   <span slot="tooltip-content">Tooltip content with custom settings</span>
 * </fabric-tooltip>
 * ```
 *
 * ## Available Inputs
 * - `position: PositioningShorthandValues` - Position of the tooltip relative to the trigger (e.g., 'top', 'bottom', 'left', 'right')
 * - `open: boolean` - Whether the tooltip is open (default: false)
 * - `beak: boolean` - Whether the tooltip has a visual beak/arrow pointer (default: false)
 * - `targetId: string` - Custom ID for the tooltip element (auto-generated if not provided)
 * - `transitionDuration: number` - Duration of tooltip transition in ms (default: 100)
 * - `transitionDelay: number` - Delay before tooltip transition in ms (default: 0)
 *
 * ## Available Events
 * - `hidePopover` - Emitted when the tooltip is hidden
 *   - Example: `<fabric-tooltip (hidePopover)="onHide($event)"></fabric-tooltip>`
 * - `showPopover` - Emitted when the tooltip is shown
 *   - Example: `<fabric-tooltip (showPopover)="onShow($event)"></fabric-tooltip>`
 *
 * ## Available Outputs
 * - `hidePopover: EventEmitter<any>` - Emitted when the tooltip is hidden
 * - `showPopover: EventEmitter<any>` - Emitted when the tooltip is shown
 *
 * ## Available Slots
 * - `tooltip-trigger` - Element that triggers the tooltip
 * - `tooltip-content` - Content to display in the tooltip
 *
 * @example
 * // In your module:
 * import { TooltipProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TooltipProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-tooltip
 *   [position]="'right'"
 *   [beak]="true"
 *   (showPopover)="onTooltipShown()"
 *   (hidePopover)="onTooltipHidden()">
 *   <button slot="tooltip-trigger">Help</button>
 *   <div slot="tooltip-content">
 *     <p>This feature allows you to configure advanced settings.</p>
 *   </div>
 * </fabric-tooltip>
 */
export declare class TooltipProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TooltipProxyModule, [typeof i1.TooltipComponent], [typeof i2.CommonModule], [typeof i1.TooltipComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TooltipProxyModule>;
}
//# sourceMappingURL=tooltip.module.d.ts.map