import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./wizard-panel.component";
import * as i2 from "@angular/common";
/**
 * @description
 * WizardPanelProxyModule provides an Angular wrapper for the Fabric WizardPanel web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard-panel>
 *   Panel content goes here
 * </fabric-wizard-panel>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard-panel
 *   [hidden]="!isCurrentStep"
 *   [active]="isCurrentStep"
 *   [state]="stepState"
 *   [id]="'step-panel-1'"
 *   [slot]="'panel'"
 *   (panelchange)="onPanelChange($event)">
 *   Step content
 * </fabric-wizard-panel>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-wizard-panel>
 *   <div slot="title">Step Title</div>
 *   <div>Main content for this step</div>
 *   <div slot="start">Content at the start</div>
 *   <div slot="end">Content at the end</div>
 *   <div slot="footer">
 *     <fabric-button (click)="goBack()">Back</fabric-button>
 *     <fabric-button (click)="goNext()">Next</fabric-button>
 *   </div>
 * </fabric-wizard-panel>
 * ```
 *
 * ## Available Inputs
 * - `hidden: boolean` - Indicates whether the panel is hidden (default: true)
 * - `state: WizardStepState` - The state of the step: 'incomplete' | 'complete' | 'error' (default: 'incomplete')
 * - `active: boolean` - Indicates whether the panel is currently active (default: false)
 * - `id: string` - The ID of the panel
 * - `slot: string` - The slot of the panel (typically 'panel' when used within a wizard)
 * - `ariaLabel: string` - The aria-label of the panel for accessibility
 * - `ariaDescribedby: string` - The aria-describedby of the panel for accessibility
 * - `ariaLabelledby: string` - The aria-labelledby of the panel for accessibility
 *
 * ## Available Events
 * - `panelchange` - Emitted when the panel state, activity, or visibility changes
 *   - Example: `<fabric-wizard-panel (panelchange)="onPanelChange($event)"></fabric-wizard-panel>`
 *
 * ## Available Outputs
 * - `panelchange: EventEmitter<any>` - Emitted when the panel state changes
 *
 * ## Available Slots
 * - Default slot - The main content of the panel
 * - `start` - Content displayed at the start of the panel
 * - `end` - Content displayed at the end of the panel
 * - `title` - Content displayed as the title of the panel
 * - `footer` - Content displayed in the footer of the panel (typically navigation buttons)
 *
 * @example
 * // In your module:
 * import { WizardPanelProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [WizardPanelProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-wizard-panel
 *   [active]="currentStepIndex === 0"
 *   [state]="step1Completed ? 'complete' : 'incomplete'"
 *   [slot]="'panel'"
 *   (panelchange)="onPanel1Change($event)">
 *   <h3 slot="title">Personal Information</h3>
 *   <div>
 *     <!-- Form fields for personal information -->
 *   </div>
 *   <div slot="footer">
 *     <fabric-button (click)="goToNextStep()">Next</fabric-button>
 *   </div>
 * </fabric-wizard-panel>
 */
export declare class WizardPanelProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<WizardPanelProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<WizardPanelProxyModule, [typeof i1.WizardPanelComponent], [typeof i2.CommonModule], [typeof i1.WizardPanelComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<WizardPanelProxyModule>;
}
//# sourceMappingURL=wizard-panel.module.d.ts.map