import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./wizard-step.component";
import * as i2 from "@angular/common";
/**
 * @description
 * WizardStepProxyModule provides an Angular wrapper for the Fabric WizardStep web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard-step>Step Label</fabric-wizard-step>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard-step
 *   [ordered]="true"
 *   [hideConnector]="false"
 *   [active]="isActive"
 *   [disabled]="isDisabled"
 *   [state]="'incomplete'"
 *   (stepchange)="onStepChange($event)">
 *   Step Label
 * </fabric-wizard-step>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-wizard-step>
 *   <!-- Default slot content -->
 *   Main step content
 *
 *   <!-- Content for specific states -->
 *   <span slot="incomplete">⚪</span>
 *   <span slot="complete">✓</span>
 *   <span slot="error">⚠️</span>
 *
 *   <!-- Step information -->
 *   <div slot="title">Step Title</div>
 *   <div slot="details">Additional step details</div>
 *
 *   <!-- Positioning content -->
 *   <div slot="start">Content at start</div>
 *   <div slot="end">Content at end</div>
 * </fabric-wizard-step>
 * ```
 *
 * ## Available Inputs
 * - `ordered: boolean` - Indicates whether the step is ordered with a number (default: false)
 * - `hideConnector: boolean` - Indicates whether the visual connector between steps should be hidden (default: false)
 * - `active: boolean` - Indicates whether the step is active (default: false)
 * - `disabled: boolean` - Indicates whether the step is disabled (default: false)
 * - `state: WizardStepState` - The state of the step: 'incomplete' | 'complete' | 'error' (default: 'incomplete')
 * - `ariaDescribedby: string` - The ID of an element that describes the step for accessibility
 * - `ariaLabelledby: string` - The ID of an element that labels the step for accessibility
 *
 * ## Available Events
 * - `stepchange` - Emitted when the step's state or active status changes
 *   - Example: `<fabric-wizard-step (stepchange)="onStepChange($event)"></fabric-wizard-step>`
 *
 * ## Available Outputs
 * - `stepchange: EventEmitter<any>` - Emitted when the step state changes
 *
 * ## Available Slots
 * - Default slot - The main content/label of the step
 * - `start` - Content displayed at the start of the step
 * - `end` - Content displayed at the end of the step
 * - `incomplete` - Content displayed when the step is incomplete
 * - `complete` - Content displayed when the step is complete
 * - `error` - Content displayed when the step has an error
 * - `title` - Content displayed as the title of the step
 * - `details` - Content displayed as additional details for the step
 *
 * @example
 * // In your module:
 * import { WizardStepProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [WizardStepProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component template:
 * <fabric-wizard-step
 *   [active]="currentStep === 0"
 *   [state]="step1State"
 *   (stepchange)="handleStepChange($event)">
 *   <div slot="title">Account Information</div>
 *   <div slot="details">Enter your basic account details</div>
 * </fabric-wizard-step>
 */
export declare class WizardStepProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<WizardStepProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<WizardStepProxyModule, [typeof i1.WizardStepComponent], [typeof i2.CommonModule], [typeof i1.WizardStepComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<WizardStepProxyModule>;
}
//# sourceMappingURL=wizard-step.module.d.ts.map